------------------------------------------------------------------------- 
--
-- Licensed Materials - Property of IBM
-- 5724-B99MQ
-- 
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
-- 
-- File Information: MQS/MQS_TEDW/src/tedw_apps_etl/ctq/pkg/v110/cdw/dml/ctq_cdw_data.sql, MQS_TEDW, amsmqs_5.1.1, 200405251803
-- Revision: 1.18
-- Date: 2/3/04 15:02:50
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Static data for IBM Tivoli Monitoring for Business Integration, 
-- Version 5.1.0 : WebSphere MQ
-----------------------------------------------------------------------                                                                       

-- create temporary table for component types
DECLARE global temporary TABLE CompTyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

-- Insert all time values in UTC
INSERT INTO session.CompTyp VALUES ('CTQ_HOST', NULL, 'WebSphere MQ host', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.CompTyp VALUES ('CTQ_QMGR', NULL, 'WebSphere MQ queue manager', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.CompTyp VALUES ('CTQ_QUEUE', NULL, 'WebSphere MQ queue', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.CompTyp VALUES ('CTQ_CHANNEL', NULL, 'WebSphere MQ channel', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

-- Insert the WebSphere MQ component types into the generic schema if not exist already
INSERT INTO TWG.CompTyp (CompTyp_Cd, CompTyp_Parent_Cd, CompTyp_Nm, CompTyp_Strt_DtTm, 
                         CompTyp_End_DtTm)
SELECT 
   c.CompTyp_Cd,
   c.CompTyp_Parent_Cd,
   c.CompTyp_Nm,
   c.CompTyp_Strt_DtTm,
   c.CompTyp_End_DtTm
FROM
   session.CompTyp c
WHERE NOT EXISTS 
(
  SELECT 1 FROM
  TWG.CompTyp t 
  WHERE
  t.CompTyp_Cd = c.CompTyp_Cd
);


-- create temporary table for relationship rules
DECLARE global temporary TABLE RelnRul (
      CompTyp_Source_Cd    CHAR(17) NOT NULL,
      CompTyp_Target_Cd    CHAR(17) NOT NULL,
		RelnTyp_Cd           VARCHAR(6) NOT NULL,
		RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
      RelnRul_End_DtTm     TIMESTAMP NOT NULL 
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.RelnRul VALUES('IP_HOST', 'CTQ_QMGR', 'PCHILD', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.RelnRul VALUES('IP_INTERFACE', 'CTQ_QMGR', 'PCHILD', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.RelnRul VALUES('CTQ_HOST', 'CTQ_QMGR', 'PCHILD', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.RelnRul VALUES('CTQ_QMGR', 'CTQ_QUEUE', 'PCHILD', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.RelnRul VALUES('CTQ_QMGR', 'CTQ_CHANNEL', 'PCHILD', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000');


-- Insert the WebSphere MQ relationship rules into the generic schema if not exist already
INSERT INTO TWG.RelnRul (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd, RelnRul_Strt_DtTm, 
                         RelnRul_End_DtTm)
SELECT 
   r.CompTyp_Source_Cd,
   r.CompTyp_Target_Cd,
   r.RelnTyp_Cd,
   r.RelnRul_Strt_DtTm,
   r.RelnRul_End_DtTm
FROM 
   session.RelnRul r
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.RelnRul t
  WHERE
  t.CompTyp_Source_Cd = r.CompTyp_Source_Cd AND 
  t.CompTyp_Target_Cd = r.CompTyp_Target_Cd AND
  t.RelnTyp_Cd = r.RelnTyp_Cd
);


-- create temporary table for attribute types
DECLARE global temporary TABLE AttrTyp (
      AttrTyp_Cd           CHAR(17) NOT NULL,
      AttrTyp_Nm           VARCHAR(120) NOT NULL
       
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;
INSERT INTO session.AttrTyp VALUES('CTQ_QMGRPLATFORM', 'WebSphere MQ queue manager platform type');
INSERT INTO session.AttrTyp VALUES('CTQ_QMGRCMDLVL', 'WebSphere MQ queue manager command level');
INSERT INTO session.AttrTyp VALUES('CTQ_QUEUETYPE', 'WebSphere MQ queue type');
INSERT INTO session.AttrTyp VALUES('CTQ_QUEUEUSAGE',  'WebSphere MQ queue usage');
INSERT INTO session.AttrTyp VALUES('CTQ_CHANNELTYPE', 'WebSphere MQ channel type');
INSERT INTO session.AttrTyp VALUES('CTQ_CHANNELPROT', 'WebSphere MQ channel protocol');
INSERT INTO session.AttrTyp VALUES('CTQ_CHANNELTRANS', 'WebSphere MQ channel transmission queue');


-- Insert the WebSphere MQ attribute types into the generic schema if not exist already
INSERT INTO TWG.AttrTyp (AttrTyp_Cd, AttrTyp_Nm)
SELECT 
   a.AttrTyp_Cd,
   a.AttrTyp_Nm
FROM
   session.AttrTyp a
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.AttrTyp t
  WHERE
  t.AttrTyp_Cd = a.AttrTyp_Cd 
);


-- create temporary table for attribute rules
DECLARE global temporary TABLE AttrRul (
      CompTyp_Cd           CHAR(17) NOT NULL,
      AttrTyp_Cd           CHAR(17) NOT NULL,
		AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
      AttrRul_End_DtTm     TIMESTAMP NOT NULL,
		AttrRul_Dom_Ind		CHAR        
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.AttrRul VALUES('CTQ_HOST', 'AMX_EID', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_HOST', 'AMX_GMT_OFFSET', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_QMGR', 'CTQ_QMGRPLATFORM', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_QMGR', 'CTQ_QMGRCMDLVL', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_QUEUE', 'CTQ_QUEUETYPE', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_QUEUE', 'CTQ_QUEUEUSAGE', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_CHANNEL', 'CTQ_CHANNELTYPE', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_CHANNEL', 'CTQ_CHANNELPROT', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');
INSERT INTO session.AttrRul VALUES('CTQ_CHANNEL', 'CTQ_CHANNELTRANS', CURRENT timestamp - CURRENT timezone, '9999-01-01-12.00.00.000000', 'N');


-- Insert the WebSphere MQ attribute rules into the generic schema if not exist already
INSERT INTO TWG.AttrRul (CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, AttrRul_End_DtTm, 
                         AttrRul_Dom_Ind)
SELECT 
   a.CompTyp_Cd,
   a.AttrTyp_Cd,
   a.AttrRul_Strt_DtTm,
   a.AttrRul_End_DtTm,
   a.AttrRul_Dom_Ind
FROM 
   session.AttrRul a
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.AttrRul t
  WHERE
  t.CompTyp_Cd = a.CompTyp_Cd AND 
  t.AttrTyp_Cd = a.AttrTyp_Cd
);


-- create temporary table for measurement source codes
DECLARE global temporary TABLE MSrc (
      MSrc_Cd              CHAR(6) NOT NULL,
      MSrc_Parent_Cd       CHAR(6),
      MSrc_Nm              VARCHAR(120) NOT NULL
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;


INSERT INTO session.msrc VALUES ('CTQ', 'AMX', 'IBM Tivoli Monitoring for Business Integration, Version 5.1.1 : WebSphere MQ');

-- Insert the WebSphere MQ measurement source code into the generic schema if not exist already
INSERT INTO TWG.MSrc (MSrc_Cd, MSrc_Parent_Cd, MSrc_Nm)
SELECT 
   m.MSrc_Cd,
   m.MSrc_Parent_Cd,
   m.MSrc_Nm
FROM 
   session.MSrc m
WHERE NOT EXISTS 
(
  SELECT 1 FROM
  TWG.MSrc t WHERE
  t.MSrc_Cd = m.MSrc_Cd
);


-- create temporary table for measurement types
DECLARE global temporary TABLE MsmtTyp (
       MsmtTyp_ID           INTEGER NOT NULL,
		 MUnit_Cd             CHAR(6) NOT NULL,
		 MSrc_Cd 	          CHAR(6) NOT NULL,
       MsmtTyp_Nm           VARCHAR(120) NOT NULL,
		 MsmtTyp_Ds           VARCHAR(254) 
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Queue_manager_status_up', 'Queue manager status up');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Queue_manager_status_down', 'Queue manager status down');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Queue_manager_status_unknown', 'Queue manager status unknown');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Dead_letter_queue_messages', 'Number of messages that are outstanding in the dead-letter queue for a queue manager');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Number_of_channels_active', 'Number of channels that are active for a queue manager');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Percentage_of_channels_active', 'Percentage of channels that are active for a queue manager');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Number_of_channels_not_active', 'Number of channels that are not active for a queue manager ');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Percentage_of_channels_not_active', 'Percentage of channels that are not active for a queue manager');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Page_set_used', 'Percentage used of the total pages in a page set for a queue manager');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Page_set_unused', 'Percentage that is not used of the total pages in a page set for a queue manager');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Command_server_status_up', 'Command server status up');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Command_server_status_down', 'Command server status down');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Command_server_status_unknown', 'Command server status unknown');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_initiator_status_up', 'Channel initiator status up');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_initiator_status_down', 'Channel initiator status down');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_initiator_status_unknown', 'Channel initiator status unknown');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_listener_status_up', 'Channel listener status up');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_listener_status_down', 'Channel listener status down ');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_listener_status_unknown', 'Channel listener status unknown ');
INSERT INTO session.MsmtTyp VALUES(0, 'KB', 'CTQ', 'TEC_cache_size', 'Size of the Tivoli Enterprise Console cache file');

INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_running', 'Channel status running');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_inactive', 'Channel status inactive');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_stopped', 'Channel status stopped');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_starting', 'Channel status starting');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_retrying', 'Channel status retrying');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_initializing', 'Channel status initializing');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_binding', 'Channel status binding');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_requesting', 'Channel status requesting');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_paused', 'Channel status paused');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_stopping', 'Channel status stopping');   
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Channel_status_unknown', 'Channel status unknown');   
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Channel_messages', 'Number of messages sent or received by a channel');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Channel_batches_completed', 'Number of completed batches by a channel');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Channel_buffers_sent', 'Number of transmission buffers sent by a channel');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Channel_buffers_received', 'Number of transmission buffers received by a channel');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Channel_bytes_sent', 'Number of bytes sent by a channel');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Channel_bytes_received', 'Number of bytes received by a channel');

INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Queue_messages_outstanding', 'Number of messages that are outstanding in a message queue');
INSERT INTO session.MsmtTyp VALUES(0, 'PRC', 'CTQ', 'Queue_used_percentage', 'Percentage used of a queue where percentage is the number of outstanding messages divided by the maximum number of messages allowed in the queue');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Input_handles', 'Number of input handles open for a queue');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Output_handles', 'Number of output handles open for a queue');
INSERT INTO session.MsmtTyp VALUES(0, 'Min', 'CTQ', 'Oldest_message', 'Oldest message outstanding in a message queue');
INSERT INTO session.MsmtTyp VALUES(0, 'KB', 'CTQ', 'Largest_message', 'Largest message outstanding in a message queue');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Peak_queue_depth', 'Peak queue depth for a queue');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Queue_messages_in', 'Number of messages that have been put on the queue');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Queue_messages_out', 'Number of messages that have been successfully retrieved from the queue');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Queue_messages_in_per_minute', 'Number of messages put on the queue per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Queue_messages_out_per_minute', 'Number of messages retrieved from the queue per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Sec', 'CTQ', 'Queue_reset_interval', 'Time since queue last reset');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_messages_per_minute', 'Number of messages sent or received by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_batches_completed_per_minute', 'Number of completed batches by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_buffers_sent_per_minute', 'Number of transmission buffers sent by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_buffers_received_per_minute', 'Number of transmission buffers received by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_bytes_sent_per_minute', 'Number of bytes sent by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_bytes_received_per_minute', 'Number of bytes received by a channel per minute');


-- Insert the WebSphere MQ measurement types into the generic schema if not exist already
INSERT INTO TWG.MsmtTyp (MsmtTyp_ID, MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) 
SELECT  
   m.MsmtTyp_ID,
   m.MUnit_Cd,
   m.MSrc_Cd,
   m.MsmtTyp_Nm,
   m.MsmtTyp_Ds
FROM
   session.MsmtTyp m
WHERE NOT EXISTS
( 
  SELECT 1 FROM
   TWG.MsmtTyp t
  WHERE
  t.MsmtTyp_Nm = m.MsmtTyp_Nm
);


-- create temporary table for measurement groups
DECLARE global temporary TABLE MGrp (
  MGrp_Cd              CHAR(6) NOT NULL,
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrp_Parent_Cd       CHAR(6),
  MGrp_Nm              VARCHAR(120) NOT NULL
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.MGrp VALUES ('CTQRST','STATE', NULL, 'Queue manager percent in state measurements');
INSERT INTO session.MGrp VALUES ('CTQSVR','STATE', NULL, 'Command server percent in state measurements');
INSERT INTO session.MGrp VALUES ('CTQINT','STATE', NULL, 'Channel initiator percent in state measurements');
INSERT INTO session.MGrp VALUES ('CTQLIS','STATE', NULL, 'Channel listener percent in state measurements');
INSERT INTO session.MGrp VALUES ('CTQLST','STATE', NULL, 'Channel percent in state measurements');


INSERT INTO TWG.MGrp (MGrp_Cd, MGrpTyp_Cd, MGrp_Parent_Cd, MGrp_Nm)
SELECT 
   s.MGrp_Cd,
   s.MGrpTyp_Cd,
   s.MGrp_Parent_Cd,
   s.MGrp_Nm
FROM 
   session.MGrp s
WHERE NOT EXISTS (
  SELECT 1 FROM
  TWG.MGrp t 
  WHERE
  t.MGrp_Cd = s.MGrp_Cd AND
  t.MGrpTyp_Cd = s.MGrpTyp_Cd
);


-- create temporary table for measurement group members
DECLARE global temporary TABLE MGrpMbr (
      MGrp_Cd              CHAR(6) NOT NULL,
		MGrpTyp_Cd           CHAR(6) NOT NULL,
		MsmtTyp_ID           INTEGER
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;
   

INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQRST',
	'STATE',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
   (
		'Queue_manager_status_up',
		'Queue_manager_status_down',
      'Queue_manager_status_unknown'
   );


INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQSVR',
	'STATE',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
   (
		'Command_server_status_up',
		'Command_server_status_down',
      'Command_server_status_unknown'
   );


INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQINT',
	'STATE',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
   (
		'Channel_initiator_status_up',
		'Channel_initiator_status_down',
      'Channel_initiator_status_unknown'
   );


INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQLIS',
	'STATE',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
   (
		'Channel_listener_status_up',
		'Channel_listener_status_down',
      'Channel_listener_status_unknown'
   );


INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQLST',
	'STATE',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
   (
		'Channel_status_inactive',
		'Channel_status_stopped',
      'Channel_status_starting',
      'Channel_status_retrying',
      'Channel_status_initializing',
      'Channel_status_binding',
      'Channel_status_requesting',
      'Channel_status_running',
      'Channel_status_paused',
      'Channel_status_stopping',
      'Channel_status_unknown'
   );


INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'MIN_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
   (
   'Queue_messages_in_per_minute',
   		'Queue_messages_out_per_minute',
   		'Queue_reset_interval',
   		'Channel_messages_per_minute',
   	    'Channel_batches_completed_per_minute',
   	    'Channel_buffers_sent_per_minute',
   	    'Channel_buffers_received_per_minute',
   	    'Channel_bytes_sent_per_minute',
        'Channel_bytes_received_per_minute',
		'Dead_letter_queue_messages',
		'Number_of_channels_active',
		'Percentage_of_channels_active',
		'Number_of_channels_not_active',
		'Percentage_of_channels_not_active',
		'Page_set_used',
		'Page_set_unused',
		'TEC_cache_size',
      'Queue_messages_outstanding',
		'Queue_used_percentage',
		'Input_handles',
		'Output_handles',
		'Oldest_message',
		'Largest_message',
		'Peak_queue_depth'
   );
	

INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'MAX_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN 
	(
		'Queue_messages_in_per_minute',
		'Queue_messages_out_per_minute',
		'Queue_reset_interval',
		'Channel_messages_per_minute',
	    'Channel_batches_completed_per_minute',
	    'Channel_buffers_sent_per_minute',
	    'Channel_buffers_received_per_minute',
	    'Channel_bytes_sent_per_minute',
        'Channel_bytes_received_per_minute',
		'Dead_letter_queue_messages',
		'Number_of_channels_active',
		'Percentage_of_channels_active',
		'Number_of_channels_not_active',
		'Percentage_of_channels_not_active',
		'Page_set_used',
		'Page_set_unused',
		'TEC_cache_size',
      'Queue_messages_outstanding',
		'Queue_used_percentage',
		'Input_handles',
		'Output_handles',
		'Oldest_message',
		'Largest_message',
		'Peak_queue_depth'
	);


INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'AVG_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
	( 	'Queue_messages_in_per_minute',
		'Queue_messages_out_per_minute',
		'Queue_reset_interval',
	  'Channel_messages_per_minute',
	  		      'Channel_batches_completed_per_minute',
	  		      'Channel_buffers_sent_per_minute',
	  		      'Channel_buffers_received_per_minute',
	  		      'Channel_bytes_sent_per_minute',
      'Channel_bytes_received_per_minute',
      'Queue_manager_status_up',
      'Queue_manager_status_down',
      'Queue_manager_status_unknown',
      'Dead_letter_queue_messages',
		'Number_of_channels_active',
		'Percentage_of_channels_active',
		'Number_of_channels_not_active',
		'Percentage_of_channels_not_active',
		'Page_set_used',
		'Page_set_unused',
      'Command_server_status_up',
      'Command_server_status_down',
      'Command_server_status_unknown',
      'Channel_initiator_status_up',
      'Channel_initiator_status_down',
      'Channel_initiator_status_unknown',
      'Channel_listener_status_up',
      'Channel_listener_status_down',
      'Channel_listener_status_unknown',
      'TEC_cache_size',
      'Channel_status_inactive',
      'Channel_status_stopped',
      'Channel_status_starting',
      'Channel_status_retrying',
      'Channel_status_initializing',
      'Channel_status_binding',
      'Channel_status_requesting',
      'Channel_status_running',
      'Channel_status_paused',
      'Channel_status_stopping',
      'Channel_status_unknown',
      'Queue_messages_outstanding',
		'Queue_used_percentage',
		'Input_handles',
		'Output_handles',
      'Oldest_message',
		'Largest_message',
		'Peak_queue_depth'
   );	
	

INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'TOT_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
	(
      'Channel_messages',
      'Channel_batches_completed',
      'Channel_buffers_sent',
      'Channel_buffers_received',
      'Channel_bytes_sent',
      'Channel_bytes_received',
	  'Queue_messages_in',
		'Queue_messages_out'
   );                   

	
-- Insert the measurment group members into the generic schema if not exist already
INSERT INTO TWG.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT 
   m.MGrp_Cd,
   m.MGrpTyp_Cd,
   m.MsmtTyp_ID
FROM 
   session.MGrpMbr m
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.MGrpMbr t
  WHERE
  t.MGrpTyp_Cd = m.MGrpTyp_CD AND 
  t.MGrp_Cd = m.MGrp_Cd AND 
  t.MsmtTyp_ID = m.MsmtTyp_ID
);
	

-- create temporary table for measurement rules
DECLARE global temporary TABLE MsmtRul (
      CompTyp_Cd           CHAR(17) NOT NULL,
		MsmtTyp_ID           INTEGER
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;


INSERT INTO session.MsmtRul (CompTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQ_QMGR',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN 
	(  
	   'Queue_manager_status_up',
      'Queue_manager_status_down',
      'Queue_manager_status_unknown',
      'Dead_letter_queue_messages',
		'Number_of_channels_active',
		'Percentage_of_channels_active',
		'Number_of_channels_not_active',
		'Percentage_of_channels_not_active',
		'Page_set_used',
		'Page_set_unused',
      'Command_server_status_up',
      'Command_server_status_down',
      'Command_server_status_unknown',
      'Channel_initiator_status_up',
      'Channel_initiator_status_down',
      'Channel_initiator_status_unknown',
      'Channel_listener_status_up',
      'Channel_listener_status_down',
      'Channel_listener_status_unknown',
      'TEC_cache_size'
	  
   );
	
INSERT INTO session.MsmtRul (CompTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQ_QUEUE',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
	(
   	'Queue_messages_outstanding',
		'Queue_used_percentage',
		'Input_handles',
		'Output_handles',
		'Oldest_message',
		'Largest_message',
		'Peak_queue_depth',
		'Queue_messages_in',
			  		'Queue_messages_out',
			  		'Queue_messages_in_per_minute',
			  		'Queue_messages_out_per_minute',
		'Queue_reset_interval'
   );
	
INSERT INTO session.MsmtRul (CompTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQ_CHANNEL',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN 
	(
      'Channel_status_inactive',
      'Channel_status_stopped',
      'Channel_status_starting',
      'Channel_status_retrying',
      'Channel_status_initializing',
      'Channel_status_binding',
      'Channel_status_requesting',
      'Channel_status_running',
      'Channel_status_paused',
      'Channel_status_stopping',
      'Channel_status_unknown',
      'Channel_messages',
      'Channel_batches_completed',
      'Channel_buffers_sent',
      'Channel_buffers_received',
      'Channel_bytes_sent',
      'Channel_bytes_received',
	  'Channel_messages_per_minute',
      'Channel_batches_completed_per_minute',
      'Channel_buffers_sent_per_minute',
      'Channel_buffers_received_per_minute',
      'Channel_bytes_sent_per_minute',
      'Channel_bytes_received_per_minute'
	);
	

-- Insert the measurement rules in the generic schema if not exist already
INSERT INTO TWG.MsmtRul (CompTyp_Cd, MsmtTyp_ID)
SELECT 
   m.CompTyp_Cd,
   m.MsmtTyp_ID
FROM 
   session.MsmtRul m
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.MsmtRul t
  WHERE
  t.CompTyp_Cd = m.CompTyp_Cd AND 
  t.MsmtTyp_ID = m.MsmtTyp_ID
);
	

-----------------------------------------------------------------------
-- Insert data into control table for pruning data from Msmt table.
-- A date duration is decimal(8,0) and has the format yyyymmdd.
-----------------------------------------------------------------------

-- create temporary table for prune measurement control
DECLARE global temporary TABLE prune_msmt_control(
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.Prune_Msmt_Control VALUES ('CTQ', 'H', 00000300);
INSERT INTO session.Prune_Msmt_Control VALUES ('CTQ', 'D', 00000300);
INSERT INTO session.Prune_Msmt_Control VALUES ('CTQ', 'W', 00010000);
INSERT INTO session.Prune_Msmt_Control VALUES ('CTQ', 'M', 00010000);

INSERT INTO TWG.Prune_Msmt_Control (MSrc_Cd, TmSum_Cd, PMsmtC_Age_In_Days)
SELECT 
   s.MSrc_Cd,
   s.TmSum_Cd,
   s.PMsmtC_Age_In_Days
FROM 
   session.Prune_Msmt_Control s
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.Prune_Msmt_Control t
  WHERE
  t.MSrc_Cd = s.MSrc_Cd AND
  t.TmSum_Cd = s.TmSum_Cd
);
 

-----------------------------------------------------------------------
-- Insert data used for translation between IBM Tivoli Monitoring and
-- Tivoli Enterprise Data Warehouse
----------------------------------------------------------------------- 

-----------------------------------------------------------------------
-- Insert data to link ITM resource names to WebSphere MQ component types
----------------------------------------------------------------------- 

-- create temporary table for resource translation values
DECLARE global temporary TABLE AMX_Resource_Trans (
   resource        	      VARCHAR(254) NOT NULL,
 	CompTyp_Cd     	      VARCHAR(17) NOT NULL
	)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_Queue_Manager', 'CTQ_QMGR');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_Queue', 'CTQ_QUEUE');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_Channel', 'CTQ_CHANNEL');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_OS390_Queue_Manager', 'CTQ_OS390_QMGR');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_OS390_Queue', 'CTQ_OS390_QUEUE');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_OS390_Channel', 'CTQ_OS390_CHANNEL');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_RA_Queue_Manager', 'CTQ_RA_QMGR');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_RA_Queue', 'CTQ_RA_QUEUE');
INSERT INTO session.AMX_Resource_Trans VALUES ('WebSphere_MQ_RA_Channel', 'CTQ_RA_CHANNEL');

INSERT INTO AMX.Resource_Transl (resource, CompTyp_Cd) 
SELECT 
   t.resource,
   t.CompTyp_Cd
FROM 
   session.AMX_Resource_Trans t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.Resource_Transl r
  WHERE
  t.CompTyp_cd = r.CompTyp_cd
);


-----------------------------------------------------------------------
-- Insert data to link ITM Category to WebSphere MQ AVA code
----------------------------------------------------------------------- 

-- create temporary table for category translation values
DECLARE global temporary TABLE AMX_Category_Trans (
   category        	      VARCHAR(254) NOT NULL,
 	Msrc_cd          	      CHAR(3) NOT NULL
	)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.AMX_Category_Trans VALUES ('WebSphere_MQ', 'CTQ');

INSERT INTO AMX.Category_Transl (category, Msrc_Cd)
SELECT 
   t.category,
   t.Msrc_cd
FROM 
   session.AMX_Category_Trans t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.Category_Transl c
  WHERE
  t.Msrc_cd = c.Msrc_cd
);


-----------------------------------------------------------------------
-- Insert data to define ITM key properties and to define what properties
-- define the WebSphere MQ component name
----------------------------------------------------------------------- 

-- create temporary table for component type translation values
DECLARE global temporary TABLE AMX_CompTyp_Transl (
   Msrc_cd        	      CHAR(3) NOT NULL,
   ITM_key_property        VARCHAR(2096) NOT NULL,
   CompTyp_cd              VARCHAR(17) NOT NULL,
 	Comp_Format_nm      	   VARCHAR(254) NOT NULL
	)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Queue_Manager.Queue_manager_name', 'CTQ_QMGR', 'WebSphere_MQ_Queue_Manager.Queue_manager_name');
INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Queue.Queue_name', 'CTQ_QUEUE', 'WebSphere_MQ_Queue.Queue_name');
INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Channel.Channel_name', 'CTQ_CHANNEL', 'WebSphere_MQ_Channel.Channel_name');

INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue_Manager.Queue_manager_name', 'CTQ_OS390_QMGR', 'WebSphere_MQ_OS390_Queue_Manager.Queue_manager_name');
INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue.Queue_name', 'CTQ_OS390_QUEUE', 'WebSphere_MQ_OS390_Queue.Queue_name');
INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Channel.Channel_name', 'CTQ_OS390_CHANNEL', 'WebSphere_MQ_OS390_Channel.Channel_name');

INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue_Manager.Queue_manager_name', 'CTQ_RA_QMGR', 'WebSphere_MQ_RA_Queue_Manager.Queue_manager_name');
INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue.Queue_name', 'CTQ_RA_QUEUE', 'WebSphere_MQ_RA_Queue.Queue_name');
INSERT INTO session.AMX_CompTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Channel.Channel_name', 'CTQ_RA_CHANNEL', 'WebSphere_MQ_RA_Channel.Channel_name');



INSERT INTO AMX.CompTyp_Transl (Msrc_Cd, ITM_key_property, CompTyp_Cd, Comp_Format_nm)
SELECT 
   t.Msrc_cd,
   t.ITM_key_property,
   t.CompTyp_cd,
   t.Comp_Format_nm
FROM 
   session.AMX_CompTyp_Transl t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.CompTyp_Transl c
  WHERE
  t.Msrc_cd = c.Msrc_cd AND 
  t.CompTyp_cd = c.CompTyp_cd 
);


-----------------------------------------------------------------------
-- Insert data to link ITM attribute properties with WebSphere MQ attribute types
------------------------------------------------------------------------ 

-- create temporary table for attribute type translation values
DECLARE global temporary TABLE AMX_AttrTyp_Transl (
   Msrc_cd          	      CHAR(3) NOT NULL,
   ITM_attr_property       VARCHAR(254) NOT NULL,
   AttrTyp_cd              VARCHAR(17) NOT NULL
	)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Queue_Manager.Queue_manager_platform', 'CTQ_QMGRPLATFORM');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Queue_Manager.Queue_manager_command_level', 'CTQ_QMGRCMDLVL');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Queue.Queue_type', 'CTQ_QUEUETYPE');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Queue.Queue_usage', 'CTQ_QUEUEUSAGE');     
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Channel.Transmission_queue_name', 'CTQ_CHANNELTRANS');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Channel.Channel_type', 'CTQ_CHANNELTYPE');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_Channel.Channel_protocol', 'CTQ_CHANNELPROT');

INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue_Manager.CTQ_HOST', 'CTQ_HOST');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue_Manager.LAST_IP_ADDRESS', 'LAST_IP_ADDRESS');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue_Manager.Queue_manager_platform', 'CTQ_QMGRPLATFORM');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue_Manager.Queue_manager_command_level', 'CTQ_QMGRCMDLVL');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue.Queue_type', 'CTQ_QUEUETYPE');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Queue.Queue_usage', 'CTQ_QUEUEUSAGE');   
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Channel.Transmission_queue_name', 'CTQ_CHANNELTRANS');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Channel.Channel_type', 'CTQ_CHANNELTYPE');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_OS390_Channel.Channel_protocol', 'CTQ_CHANNELPROT');

INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue_Manager.CTQ_HOST', 'CTQ_HOST');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue_Manager.LAST_IP_ADDRESS', 'LAST_IP_ADDRESS');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue_Manager.Queue_manager_platform', 'CTQ_QMGRPLATFORM');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue_Manager.Queue_manager_command_level', 'CTQ_QMGRCMDLVL');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue.Queue_type', 'CTQ_QUEUETYPE');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Queue.Queue_usage', 'CTQ_QUEUEUSAGE');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Channel.Transmission_queue_name', 'CTQ_CHANNELTRANS');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Channel.Channel_type', 'CTQ_CHANNELTYPE');
INSERT INTO session.AMX_AttrTyp_Transl VALUES 
   ('CTQ', 'WebSphere_MQ_RA_Channel.Channel_protocol', 'CTQ_CHANNELPROT');

INSERT INTO AMX.AttrTyp_Transl (Msrc_cd, ITM_attr_property, AttrTyp_cd)
SELECT 
   t.Msrc_cd,
   t.ITM_attr_property,
   t.AttrTyp_cd
FROM 
   session.AMX_AttrTyp_Transl t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.AttrTyp_Transl a
  WHERE
  t.Msrc_cd = a.Msrc_cd AND
  t.ITM_attr_property = a.ITM_attr_property AND
  t.AttrTyp_cd = a.AttrTyp_cd
);
                  

-----------------------------------------------------------------------
-- Insert data to define relation rules for remote WebSphere MQ components
------------------------------------------------------------------------ 

-- create temporary table for relation rule translation values
DECLARE global temporary TABLE AMX_RelnRul_Transl (
   CompTyp_Source_Cd 	   VARCHAR(17) NOT NULL,
   CompTyp_Target_Cd 	   VARCHAR(17) NOT NULL,
   RelnTyp_Cd              CHAR(6) NOT NULL,
   RelnRul_Strt_DtTm    	Timestamp NOT NULL,
   RelnRul_End_DtTm        Timestamp NOT NULL
	)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;
  
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_QMGR', 'CTQ_OS390_QMGR', 'PROXY', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_QUEUE', 'CTQ_OS390_QUEUE', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_OS390_QMGR', 'CTQ_OS390_QUEUE', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_CHANNEL', 'CTQ_OS390_CHANNEL', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_OS390_QMGR', 'CTQ_OS390_CHANNEL', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_QMGR', 'CTQ_RA_QMGR', 'PROXY', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_QUEUE', 'CTQ_RA_QUEUE', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_RA_QMGR', 'CTQ_RA_QUEUE', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_CHANNEL', 'CTQ_RA_CHANNEL', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('CTQ_RA_QMGR', 'CTQ_RA_CHANNEL', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');


INSERT INTO AMX.RelnRul_Transl (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd, 
                                RelnRul_Strt_DtTm, RelnRul_End_DtTm)
SELECT 
   t.CompTyp_Source_Cd,
   t.CompTyp_Target_Cd,
   t.RelnTyp_Cd,
   t.RelnRul_Strt_DtTm,
   t.RelnRul_End_DtTm
FROM 
   session.AMX_RelnRul_Transl t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.RelnRul_Transl r
  WHERE
  t.CompTyp_Source_Cd = r.CompTyp_Source_Cd AND
  t.CompTyp_Target_Cd = r.CompTyp_Target_Cd AND
  t.RelnTyp_Cd = r.RelnTyp_Cd 
);

-----------------------------------------------------------------------
-- Static data for Extract Control  
----------------------------------------------------------------------- 

-- create temporary table for Extract control
DECLARE global temporary TABLE Extract_Control (
   ExtCtl_Source   	      VARCHAR(120) NOT NULL,
 	ExtCtl_Target   	      VARCHAR(120) NOT NULL,
 	ExtCtl_From_RawSeq      CHAR(10) FOR bit data,
 	ExtCtl_To_RawSeq        CHAR(10) FOR bit data,
 	ExtCtl_From_IntSeq      bigint NOT NULL,
 	ExtCtl_To_IntSeq        bigint NOT NULL,
 	ExtCtl_From_DtTm     	timestamp,
 	ExtCtl_To_DtTm       	timestamp
	)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;


-----------------------------------------------------------------------
-- From TWG.MSMT to the Mart Hour Fact Tables
-----------------------------------------------------------------------

INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'CTQ.F_QMGR_HOUR', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'CTQ.F_QUEUE_HOUR', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.MSMT', 'CTQ.F_CHNL_HOUR', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');



-----------------------------------------------------------------------
-- From staging tables in CDW to the Mart metric dimension tables
-----------------------------------------------------------------------

INSERT INTO session.Extract_Control VALUES ('CTQ.QMGR_METRIC', 'CTQ.D_QMGR_METRIC', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('CTQ.QUEUE_METRIC', 'CTQ.D_QUEUE_METRIC', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('CTQ.CHANNEL_METRIC', 'CTQ.D_CHANNEL_METRIC', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');


-----------------------------------------------------------------------
-- From TWG.Comp to the host component dimension table
-----------------------------------------------------------------------

INSERT INTO session.Extract_Control VALUES ('TWG.COMP', 'CTQ.D_HOST', x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');

  
-----------------------------------------------------------------------
-- From TWG.CompAttr to the component dimension tables
-----------------------------------------------------------------------

INSERT INTO session.Extract_Control VALUES ('TWG.COMPATTR', 'CTQ.D_QMGR', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMPATTR', 'CTQ.D_QUEUE', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');
INSERT INTO session.Extract_Control VALUES ('TWG.COMPATTR', 'CTQ.D_CHANNEL', x'', x'', 0, 0, '1970-01-01-00.00.00.000000', '9999-01-01-12.00.00.000000');


-- insert the static data for the extract table 
INSERT INTO TWG.Extract_control (ExtCtl_Source, ExtCtl_Target, ExtCtl_From_RawSeq, 
                                 ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, 
                                 ExtCtl_From_DtTm, ExtCtl_To_DtTm) 
SELECT 
   m.ExtCtl_Source,
   m.ExtCtl_Target,
   m.ExtCtl_From_RawSeq,
   m.ExtCtl_To_RawSeq,
   m.ExtCtl_From_IntSeq,
   m.ExtCtl_To_IntSeq,
   m.ExtCtl_From_DtTm,
   m.ExtCtl_To_DtTm  
FROM 
   session.Extract_Control m
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.Extract_Control t
  WHERE
  t.ExtCtl_Source=m.ExtCtl_Source AND
  t.ExtCtl_Target=m.ExtCtl_Target
);


-----------------------------------------------------------------------
-- Insert static data into the WebSphere MQ staging tables 
-----------------------------------------------------------------------

-- create temporary table for min_exists
DECLARE global temporary TABLE temp_min_exists (
   msmttyp_id	   INTEGER,
   min_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_min_exists (msmttyp_id, min_exists)
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MGrpMbr mb,
   TWG.Msmttyp m
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'MIN_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;


-- create temporary table for max_exists
DECLARE global temporary TABLE temp_max_exists (
   msmttyp_id	   INTEGER,
   max_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_max_exists (msmttyp_id, max_exists)
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MgrpMbr mb,
   TWG.Msmttyp m 
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'MAX_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;


-- create temporary table for avg_exists
DECLARE global temporary TABLE temp_avg_exists (
   msmttyp_id	   INTEGER,
   avg_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_avg_exists (msmttyp_id, avg_exists)
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MgrpMbr mb,
   TWG.Msmttyp m 
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'AVG_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;


-- create temporary table for tot_exists
DECLARE global temporary TABLE temp_tot_exists (
   msmttyp_id	   INTEGER,
   tot_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_tot_exists (msmttyp_id, tot_exists) 
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MgrpMbr mb,
   TWG.Msmttyp m 
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'TOT_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;

DELETE FROM CTQ.QMGR_METRIC;

INSERT INTO CTQ.QMGR_METRIC (insert_dttm, metric_id, met_name, met_desc, met_units,
                             met_category, msrc_nm, min_exists, max_exists, avg_exists,
                             total_exists)
SELECT
   current timestamp - current timezone,
   mt.msmttyp_id,
   mt.msmttyp_nm,
   mt.msmttyp_ds,
   mu1.munit_nm,
   'not used',
   ms.msrc_nm,
   value(min_exists,'N'),
   value(max.max_exists,'N'),
   value(avg.avg_exists,'N'),
   value(tot.tot_exists,'N')
FROM
   TWG.msmttyp mt left outer join session.temp_min_exists min
   ON mt.msmttyp_id = min.msmttyp_id,
   TWG.msmttyp mt2 left outer join session.temp_max_exists max
   ON mt2.msmttyp_id = max.msmttyp_id,
   TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
   ON mt3.msmttyp_id = avg.msmttyp_id,
   TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
   ON mt4.msmttyp_id = tot.msmttyp_id,
   TWG.MsmtRul mr,
   TWG.Mgrp mg1,
   TWG.MgrpMbr mb1,
   TWG.MUnit mu1,
   TWG.Msrc ms
WHERE
   mt.msmttyp_id = mr.msmttyp_id AND
   mr.comptyp_cd = 'CTQ_QMGR' AND
   mt.MSrc_Cd = 'CTQ' AND
   mt.msmttyp_id = mt2.msmttyp_id AND
   mt.msmttyp_id = mt3.msmttyp_id AND
   mt.msmttyp_id = mt4.msmttyp_id AND
   mb1.mgrp_cd = mg1.mgrp_cd AND
   mb1.mgrptyp_cd = 'GROUP' AND
   mt.munit_cd = mu1.munit_cd AND
   ms.msrc_cd = 'CTQ' AND 
   NOT EXISTS
   ( 
    SELECT 1 FROM
    CTQ.QMGR_METRIC s
    WHERE
    mt.msmttyp_id = s.metric_id
   )
GROUP BY
   mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mu1.munit_nm, ms.msrc_nm, 
   min_exists, avg_exists, tot_exists, max_exists
;

DELETE FROM CTQ.QUEUE_METRIC;

INSERT INTO CTQ.QUEUE_METRIC (insert_dttm, metric_id, met_name, met_desc, met_units,
                              met_category, msrc_nm, min_exists, max_exists, avg_exists,
                              total_exists)
SELECT
   current timestamp - current timezone,
   mt.msmttyp_id,
   mt.msmttyp_nm,
   mt.msmttyp_ds,
   mu1.munit_nm,
   'not used',
   ms.msrc_nm,
   value(min_exists,'N'),
   value(max.max_exists,'N'),
   value(avg.avg_exists,'N'),
   value(tot.tot_exists,'N')
FROM
   TWG.msmttyp mt left outer join session.temp_min_exists min
   ON mt.msmttyp_id = min.msmttyp_id,
   TWG.msmttyp mt2 left outer join session.temp_max_exists max
   ON mt2.msmttyp_id = max.msmttyp_id,
   TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
   ON mt3.msmttyp_id = avg.msmttyp_id,
   TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
   ON mt4.msmttyp_id = tot.msmttyp_id,
   TWG.MsmtRul mr,
   TWG.Mgrp mg1,
   TWG.MgrpMbr mb1,
   TWG.MUnit mu1,
   TWG.MSrc ms
WHERE
   mt.msmttyp_id = mr.msmttyp_id AND 
   mr.comptyp_cd = 'CTQ_QUEUE' AND
   mt.MSrc_Cd = 'CTQ' AND
   mt.msmttyp_id = mt2.msmttyp_id AND
   mt.msmttyp_id = mt3.msmttyp_id AND
   mt.msmttyp_id = mt4.msmttyp_id AND
   mb1.mgrp_cd = mg1.mgrp_cd AND
   mb1.mgrptyp_cd = 'GROUP' AND 
   mt.munit_cd = mu1.munit_cd AND
   ms.msrc_cd = 'CTQ' AND 
   NOT EXISTS
   ( 
    SELECT 1 FROM
    CTQ.QUEUE_METRIC s
    WHERE
    mt.msmttyp_id = s.metric_id
   ) 
GROUP BY
   mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mu1.munit_nm, ms.msrc_nm, 
   min_exists, avg_exists, tot_exists, max_exists
;

DELETE FROM CTQ.CHANNEL_METRIC;

INSERT INTO CTQ.CHANNEL_METRIC (insert_dttm, metric_id, met_name, met_desc, met_units,
                                met_category, msrc_nm, min_exists, max_exists, avg_exists,
                                total_exists)
SELECT
   current timestamp - current timezone,
   mt.msmttyp_id,
   mt.msmttyp_nm,
   mt.msmttyp_ds,
   mu1.munit_nm,
   'not used',
   ms.msrc_nm,
   value(min_exists,'N'),
   value(max.max_exists,'N'),
   value(avg.avg_exists,'N'),
   value(tot.tot_exists,'N')
FROM
   TWG.msmttyp mt left outer join session.temp_min_exists min
   ON mt.msmttyp_id = min.msmttyp_id,
   TWG.msmttyp mt2 left outer join session.temp_max_exists max
   ON mt2.msmttyp_id = max.msmttyp_id,
   TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
   ON mt3.msmttyp_id = avg.msmttyp_id,
   TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
   ON mt4.msmttyp_id = tot.msmttyp_id,
   TWG.MsmtRul mr,
   TWG.Mgrp mg1,
   TWG.MgrpMbr mb1,
   TWG.MUnit mu1,
   TWG.Msrc ms
WHERE
   mt.msmttyp_id = mr.msmttyp_id AND 
   mr.comptyp_cd = 'CTQ_CHANNEL' AND
   mt.msrc_cd = 'CTQ' AND
   mt.msmttyp_id = mt2.msmttyp_id AND
   mt.msmttyp_id = mt3.msmttyp_id AND
   mt.msmttyp_id = mt4.msmttyp_id AND
   mb1.mgrp_cd = mg1.mgrp_cd AND
   mb1.mgrptyp_cd = 'GROUP' AND
   mt.munit_cd = mu1.munit_cd AND
   ms.msrc_cd = 'CTQ' AND 
   NOT EXISTS
   ( 
    SELECT 1 FROM
    CTQ.CHANNEL_METRIC s
    WHERE
    mt.msmttyp_id = s.metric_id
   )
GROUP BY
   mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mu1.munit_nm, ms.msrc_nm, 
   min_exists, avg_exists, tot_exists, max_exists
;
