------------------------------------------------------------------------- 
--
-- Licensed Materials - Property of IBM
-- 5724-B99MQ
-- 
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
-- 
-- File Information: MQS/MQS_TEDW/src/tedw_apps_etl/ctq/pkg/v110/etl/sql/ctq_m05_s010_metric.db2, MQS_TEDW, amsmqs_5.1.1, 200405251803
-- Revision: 1.5
-- Date: 7/16/02 12:42:39
--
-----------------------------------------------------------------------

--#VERSION 1.1.0.1.0

-----------------------------------------------------------------------
-- insert WebSphere MQ queue manager metrics 
-----------------------------------------------------------------------

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTQ.STAGE_D_QMGR_MET;

--#EXECUTE_AT_TARGET
create table CTQ.STAGE_D_QMGR_MET (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );


-- set the high value for the window
update TWG.Extract_Control set
    extctl_to_intseq =  (select max(metric_id) from CTQ.QMGR_METRIC)
where  
    extctl_source='CTQ.QMGR_METRIC' and
    extctl_target='CTQ.D_QMGR_METRIC' and
    (select count(*) from CTQ.QMGR_METRIC ) > 0
;


--#INSERT_INTO_TARGET
-- insert WebSphere MQ queue manager metrics into staging table
insert into CTQ.STAGE_D_QMGR_MET (metric_id, met_name, met_desc, met_units, met_category, msrc_nm,
                                  min_exists, max_exists, avg_exists, total_exists)
select
    d.metric_id,
    d.met_name,
    d.met_desc,
    d.met_units,
    d.met_category,
    d.msrc_nm,
    d.min_exists,
    d.max_exists,
    d.avg_exists,
    d.total_exists
from
    CTQ.QMGR_METRIC d,
    TWG.Extract_Control ec
where
    ec.extctl_source = 'CTQ.QMGR_METRIC' and
    ec.extctl_target = 'CTQ.D_QMGR_METRIC' and
    d.metric_id > ec.extctl_from_intseq and
    d.metric_id <= ec.extctl_to_intseq 
;


--#EXECUTE_AT_TARGET
-- Copy WebSphere MQ queue manager metrics from staging table into metric dimension table
insert into CTQ.D_QMGR_METRIC (metric_id, met_name, met_desc, met_units, met_category, msrc_nm,
                                  min_exists, max_exists, avg_exists, total_exists)
select
    s.metric_id,
    s.met_name,
    s.met_desc,
    s.met_units,
    s.met_category,
    s.msrc_nm,
    s.min_exists,
    s.max_exists,
    s.avg_exists,
    s.total_exists
from CTQ.STAGE_D_QMGR_MET s
where not exists
(
    select 1 from 
        CTQ.D_QMGR_METRIC d
    where
        d.metric_id = s.metric_id
);

  
-- confirm insertion of data by inserting a row into TWG.EXTRACT_LOG.
insert into TWG.EXTRACT_LOG (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq,
                             extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm,
                             extlog_to_dttm)
select
    ec.extctl_source,
    ec.extctl_target,
    current timestamp - current timezone,
    ec.extctl_from_rawseq,
    ec.extctl_to_rawseq,
    ec.extctl_from_intseq,
    ec.extctl_to_intseq,
    ec.extctl_from_dttm,
    ec.extctl_to_dttm
from 
    TWG.Extract_control ec
where
    ec.extctl_source = 'CTQ.QMGR_METRIC' and
    ec.extctl_target = 'CTQ.D_QMGR_METRIC'
; 


-----------------------------------------------------------------------
-- insert WebSphere MQ queue metrics
-----------------------------------------------------------------------

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTQ.STAGE_D_QUEUE_MET;

--#EXECUTE_AT_TARGET
create table CTQ.STAGE_D_QUEUE_MET (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );

-- set the high value for the window
update TWG.Extract_Control set
    extctl_to_intseq =  (select max(metric_id) from CTQ.QUEUE_METRIC)
where  
    extctl_source='CTQ.QUEUE_METRIC' and
    extctl_target='CTQ.D_QUEUE_METRIC' and
    (select count(*) from CTQ.QUEUE_METRIC ) > 0
;

                                  
--#INSERT_INTO_TARGET
-- insert WebSphere MQ queue metrics into staging table                            
insert into CTQ.STAGE_D_QUEUE_MET (metric_id, met_name, met_desc, met_units, met_category, msrc_nm,
                                   min_exists, max_exists, avg_exists, total_exists)
select
    d.metric_id,
    d.met_name,
    d.met_desc,
    d.met_units,
    d.met_category,
    d.msrc_nm,
    d.min_exists,
    d.max_exists,
    d.avg_exists,
    d.total_exists
from
    CTQ.QUEUE_METRIC d,
    TWG.Extract_Control ec
where
    ec.extctl_source = 'CTQ.QUEUE_METRIC' and
    ec.extctl_target = 'CTQ.D_QUEUE_METRIC' and
    d.metric_id > ec.extctl_from_intseq and
    d.metric_id <= ec.extctl_to_intseq 
;


--#EXECUTE_AT_TARGET
-- Copy WebSphere MQ queue metrics from staging table into metric dimension table
insert into CTQ.D_QUEUE_METRIC (metric_id, met_name, met_desc, met_units, met_category, msrc_nm,
                                min_exists, max_exists, avg_exists, total_exists)
select 
    s.metric_id,
    s.met_name,
    s.met_desc,
    s.met_units,
    s.met_category,
    s.msrc_nm,
    s.min_exists,
    s.max_exists,
    s.avg_exists,
    s.total_exists
from CTQ.STAGE_D_QUEUE_MET s
where not exists
(
    select 1 from 
        CTQ.D_QUEUE_METRIC d
    where
        d.metric_id = s.metric_id
);                              
                       
                              
-- confirm insertion of data by inserting a row into TWG.EXTRACT_LOG.
insert into TWG.EXTRACT_LOG (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq,
                             extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm,
                             extlog_to_dttm)
select
    ec.extctl_source,
    ec.extctl_target,
    current timestamp - current timezone,
    ec.extctl_from_rawseq,
    ec.extctl_to_rawseq,
    ec.extctl_from_intseq,
    ec.extctl_to_intseq,
    ec.extctl_from_dttm,
    ec.extctl_to_dttm
from 
    TWG.Extract_control ec
where
    ec.extctl_source = 'CTQ.QUEUE_METRIC' and
    ec.extctl_target = 'CTQ.D_QUEUE_METRIC'
; 



-----------------------------------------------------------------------
-- insert WebSphere MQ channel metrics
-----------------------------------------------------------------------

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTQ.STAGE_D_CHNL_MET;

--#EXECUTE_AT_TARGET
create table CTQ.STAGE_D_CHNL_MET (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );         


-- set the high value for the window
update TWG.Extract_Control set
    extctl_to_intseq =  ( select max(metric_id) from CTQ.CHANNEL_METRIC)
where  
    extctl_source='CTQ.CHANNEL_METRIC' and
    extctl_target='CTQ.D_CHANNEL_METRIC' and
    (select count(*) from CTQ.CHANNEL_METRIC ) > 0
;


--#INSERT_INTO_TARGET
-- insert WebSphere MQ channel metrics into staging table
insert into CTQ.STAGE_D_CHNL_MET (metric_id, met_name, met_desc, met_units, met_category, msrc_nm,
                                  min_exists, max_exists, avg_exists, total_exists) 
select
    d.metric_id,
    d.met_name,
    d.met_desc,
    d.met_units,
    d.met_category,
    d.msrc_nm,
    d.min_exists,
    d.max_exists,
    d.avg_exists,
    d.total_exists
from
    CTQ.CHANNEL_METRIC d,
    TWG.Extract_Control ec
where
    ec.extctl_source = 'CTQ.CHANNEL_METRIC' and
    ec.extctl_target = 'CTQ.D_CHANNEL_METRIC' and
    d.metric_id > ec.extctl_from_intseq and
    d.metric_id <= ec.extctl_to_intseq 
;


--#EXECUTE_AT_TARGET
-- Copy WebSphere MQ channel metrics from staging table into metric dimension table
insert into CTQ.D_CHANNEL_METRIC (metric_id, met_name, met_desc, met_units, met_category, msrc_nm,
                                  min_exists, max_exists, avg_exists, total_exists)
select 
    s.metric_id,
    s.met_name,
    s.met_desc,
    s.met_units,
    s.met_category,
    s.msrc_nm,
    s.min_exists,
    s.max_exists,
    s.avg_exists,
    s.total_exists
from CTQ.STAGE_D_CHNL_MET s
where not exists
(
    select 1 from 
        CTQ.D_CHANNEL_METRIC d
    where
        d.metric_id = s.metric_id
); 

 
-- confirm insertion of data by inserting a row into TWG.EXTRACT_LOG.
insert into TWG.EXTRACT_LOG (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq,
                             extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm,
                             extlog_to_dttm)
select
    ec.extctl_source,
    ec.extctl_target,
    current timestamp - current timezone,
    ec.extctl_from_rawseq,
    ec.extctl_to_rawseq,
    ec.extctl_from_intseq,
    ec.extctl_to_intseq,
    ec.extctl_from_dttm,
    ec.extctl_to_dttm
from 
    TWG.Extract_control ec
where
    ec.extctl_source = 'CTQ.CHANNEL_METRIC' and
    ec.extctl_target = 'CTQ.D_CHANNEL_METRIC'
; 

