------------------------------------------------------------------------- 
--
-- Licensed Materials - Property of IBM
-- 5724-B99MQ
-- 
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
-- 
-- File Information: MQS/MQS_TEDW/src/tedw_apps_etl/ctq/pkg/v110/mart/ddl/ctq_mart_schema.sql, MQS_TEDW, amsmqs_5.1.1, 200405251803
-- Revision: 1.3
-- Date: 8/20/02 14:49:50
--
-----------------------------------------------------------------------

-- MART staging tables for IBM Tivoli Monitoring for Business Integration,
-- Version 5.1.0 : WebSphere MQ 
-- Owner of these tables is CTQ
-- CTQ is the unique AVA code for IBM Tivoli Monitoring for Business 
-- Integration, Version 5.1.0 : WebSphere MQ

-----------------------------------------------------------------------
-- Create metric dimension tables 
-----------------------------------------------------------------------

-- Metric dimension table for WebSphere MQ queue managers
CREATE TABLE CTQ.D_QMGR_METRIC (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );


-- Metric dimension table for WebSphere MQ queues
CREATE TABLE CTQ.D_QUEUE_METRIC (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );
    

-- Metric dimension table for WebSphere MQ channels
CREATE TABLE CTQ.D_CHANNEL_METRIC (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );         


-----------------------------------------------------------------------
-- Create component dimension tables 
-----------------------------------------------------------------------

-- Dimension table for WebSphere MQ hosts
CREATE TABLE CTQ.D_HOST (
         host_id           INTEGER NOT NULL,
         host_name         VARCHAR(254) NOT NULL,
         customer_name     VARCHAR(120) NOT NULL,
         center_name       VARCHAR(120) NOT NULL,
               primary key (host_id)
);

-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.D_V_HOST_<cust_name>  
--   AS (SELECT * FROM CTQ.D_HOST
--   WHERE customer_name = <cust_name>);


-- Dimension table for WebSphere MQ queue managers
CREATE TABLE CTQ.D_QMGR (
         qmgr_id              INTEGER NOT NULL,
         qmgr_name            VARCHAR(254) NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         platform_type        VARCHAR(120),
         command_level        VARCHAR(120),
               primary key (qmgr_id, XQ_qmgr_state_dttm)
);


-- Dimension table for WebSphere MQ queues
CREATE TABLE CTQ.D_QUEUE (
         queue_id             INTEGER NOT NULL,
         queue_name           VARCHAR(254) NOT NULL,
         XQ_queu_state_dttm   timestamp NOT NULL,
         queue_type           VARCHAR(120) NOT NULL,
         queue_usage          VARCHAR(120) NOT NULL,
               primary key (queue_id, XQ_queu_state_dttm)
);


-- Dimension table for WebSphere MQ channels
CREATE TABLE CTQ.D_CHANNEL (
         channel_id           INTEGER NOT NULL,
         channel_name         VARCHAR(254) NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         channel_type         VARCHAR(120) NOT NULL,
         protocol_type        VARCHAR(120) NOT NULL,
         transmission_queue   VARCHAR(120),
               primary key (channel_id, XQ_chnl_state_dttm)
);



-----------------------------------------------------------------------
-- Create WebSphere MQ queue manager fact tables 
-----------------------------------------------------------------------
         
-- Hour fact table for all metrics against WebSphere MQ queue managers
CREATE TABLE CTQ.F_QMGR_HOUR (
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_hour            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (qmgr_id, XQ_qmgr_state_dttm, host_id, metric_id, meas_hour)
);

-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QMGR_<cust_name>_HOUR  
--   AS (SELECT * FROM CTQ.F_QMGR_HOUR WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QMGR_HOUR
       ADD CONSTRAINT A_1
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;

ALTER TABLE CTQ.F_QMGR_HOUR
       ADD CONSTRAINT A_2
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QMGR_HOUR
       ADD CONSTRAINT A_3
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QMGR_METRIC;
                    

-- create indexes for the foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QMGR_HOUR ON CTQ.F_QMGR_HOUR (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK2F_QMGR_HOUR ON CTQ.F_QMGR_HOUR (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK3F_QMGR_HOUR ON CTQ.F_QMGR_HOUR (
       metric_id                 ASC
);


-- Day fact table for all metrics against WebSphere MQ queue managers
CREATE TABLE CTQ.F_QMGR_DAY (
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (qmgr_id, XQ_qmgr_state_dttm, host_id, metric_id, meas_date)
);

-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QMGR_<cust_name>_DAY  
--   AS (SELECT * FROM CTQ.F_QMGR_DAY WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QMGR_DAY
       ADD CONSTRAINT A_4
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;

ALTER TABLE CTQ.F_QMGR_DAY
       ADD CONSTRAINT A_5
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QMGR_DAY
       ADD CONSTRAINT A_6
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QMGR_METRIC;


-- create indexes for the foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QMGR_DAY ON CTQ.F_QMGR_DAY (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK2F_QMGR_DAY ON CTQ.F_QMGR_DAY (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK3F_QMGR_DAY ON CTQ.F_QMGR_DAY (
       metric_id                 ASC
);


-- Week fact table for all metrics against WebSphere MQ queue managers
CREATE TABLE CTQ.F_QMGR_WEEK (
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (qmgr_id, XQ_qmgr_state_dttm, host_id, metric_id, meas_date)
);
        
-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QMGR_<cust_name>_WEEK  
--   AS (SELECT * FROM CTQ.F_QMGR_WEEK WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QMGR_WEEK
       ADD CONSTRAINT A_7
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;

ALTER TABLE CTQ.F_QMGR_WEEK
       ADD CONSTRAINT A_8
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QMGR_WEEK
       ADD CONSTRAINT A_9
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QMGR_METRIC;


-- create indexes for the foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QMGR_WEEK ON CTQ.F_QMGR_WEEK (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK2F_QMGR_WEEK ON CTQ.F_QMGR_WEEK (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK3F_QMGR_WEEK ON CTQ.F_QMGR_WEEK (
       metric_id                 ASC
);


-- Month fact table for all metrics against WebSphere MQ queue managers
CREATE TABLE CTQ.F_QMGR_MONTH (
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (qmgr_id, XQ_qmgr_state_dttm, host_id, metric_id, meas_date)
);
         
-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QMGR_<cust_name>_MONTH  
--   AS (SELECT * FROM CTQ.F_QMGR_MONTH WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QMGR_MONTH
       ADD CONSTRAINT A_10
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;

ALTER TABLE CTQ.F_QMGR_MONTH
       ADD CONSTRAINT A_11
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QMGR_MONTH
       ADD CONSTRAINT A_12
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QMGR_METRIC;


-- create indexes for the foreign keys to WebSphere MQ queue manager metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QMGR_MONTH ON CTQ.F_QMGR_MONTH (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK2F_QMGR_MONTH ON CTQ.F_QMGR_MONTH (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK3F_QMGR_MONTH ON CTQ.F_QMGR_MONTH (
       metric_id                 ASC
);


-----------------------------------------------------------------------
-- Create WebSphere MQ queue fact tables 
-----------------------------------------------------------------------

-- Hour fact table for all metrics against WebSphere MQ queues 
CREATE TABLE CTQ.F_QUEUE_HOUR (
         queue_id             INTEGER NOT NULL,
         XQ_queu_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_hour            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (queue_id, XQ_queu_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_hour)
);

-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QUEUE_<cust_name>_HOUR  
--   AS (SELECT * FROM CTQ.F_QUEUE_HOUR WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QUEUE_HOUR
       ADD CONSTRAINT B_1
              FOREIGN KEY (queue_id, XQ_queu_state_dttm)
                             REFERENCES CTQ.D_QUEUE;

ALTER TABLE CTQ.F_QUEUE_HOUR
       ADD CONSTRAINT B_2
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_QUEUE_HOUR
       ADD CONSTRAINT B_3
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QUEUE_HOUR
       ADD CONSTRAINT B_4
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QUEUE_METRIC;


-- create indexes for the foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QUEUE_HOUR ON CTQ.F_QUEUE_HOUR (
       queue_id                  ASC,
       XQ_queu_state_dttm        ASC
);

CREATE INDEX CTQ.XFK2F_QUEUE_HOUR ON CTQ.F_QUEUE_HOUR (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_QUEUE_HOUR ON CTQ.F_QUEUE_HOUR (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_QUEUE_HOUR ON CTQ.F_QUEUE_HOUR (
       metric_id                 ASC
);


-- Day fact table for all metrics against WebSphere MQ queues 
CREATE TABLE CTQ.F_QUEUE_DAY (
         queue_id             INTEGER NOT NULL,
         XQ_queu_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (queue_id, XQ_queu_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_date)
);

-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QUEUE_<cust_name>_DAY  
--   AS (SELECT * FROM CTQ.F_QUEUE_DAY WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QUEUE_DAY
       ADD CONSTRAINT B_5
              FOREIGN KEY (queue_id, XQ_queu_state_dttm)
                             REFERENCES CTQ.D_QUEUE;

ALTER TABLE CTQ.F_QUEUE_DAY
       ADD CONSTRAINT B_6
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_QUEUE_DAY
       ADD CONSTRAINT B_7
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QUEUE_DAY
       ADD CONSTRAINT B_8
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QUEUE_METRIC;

-- create indexes for the foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QUEUE_DAY ON CTQ.F_QUEUE_DAY (
       queue_id                  ASC,
       XQ_queu_state_dttm        ASC
);

CREATE INDEX CTQ.XFK2F_QUEUE_DAY ON CTQ.F_QUEUE_DAY (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_QUEUE_DAY ON CTQ.F_QUEUE_DAY (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_QUEUE_DAY ON CTQ.F_QUEUE_DAY(
       metric_id                 ASC
);


-- Week fact table for all metrics against WebSphere MQ queues 
CREATE TABLE CTQ.F_QUEUE_WEEK (
         queue_id             INTEGER NOT NULL,
         XQ_queu_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (queue_id, XQ_queu_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_date)
);
         
-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QUEUE_<cust_name>_WEEK  
--   AS (SELECT * FROM CTQ.F_QUEUE_WEEK WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QUEUE_WEEK
       ADD CONSTRAINT B_9
              FOREIGN KEY (queue_id, XQ_queu_state_dttm)
                             REFERENCES CTQ.D_QUEUE;

ALTER TABLE CTQ.F_QUEUE_WEEK
       ADD CONSTRAINT B_10
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_QUEUE_WEEK
       ADD CONSTRAINT B_11
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QUEUE_WEEK
       ADD CONSTRAINT B_12
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QUEUE_METRIC;


-- create indexes for the foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QUEUE_WEEK ON CTQ.F_QUEUE_WEEK (
       queue_id                  ASC,
       XQ_queu_state_dttm        ASC
);
  
CREATE INDEX CTQ.XFK2F_QUEUE_WEEK ON CTQ.F_QUEUE_WEEK (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_QUEUE_WEEK ON CTQ.F_QUEUE_WEEK (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_QUEUE_WEEK ON CTQ.F_QUEUE_WEEK (
       metric_id                 ASC
);


-- Month fact table for all metrics against WebSphere MQ queues 
CREATE TABLE CTQ.F_QUEUE_MONTH (
         queue_id             INTEGER NOT NULL,
         XQ_queu_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (queue_id, XQ_queu_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_date)
);
         
-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_QUEUE_<cust_name>_MONTH  
--   AS (SELECT * FROM CTQ.F_QUEUE_MONTH WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_QUEUE_MONTH
       ADD CONSTRAINT B_13
              FOREIGN KEY (queue_id, XQ_queu_state_dttm)
                             REFERENCES CTQ.D_QUEUE;

ALTER TABLE CTQ.F_QUEUE_MONTH
       ADD CONSTRAINT B_14
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_QUEUE_MONTH
       ADD CONSTRAINT B_15
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_QUEUE_MONTH
       ADD CONSTRAINT B_16
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_QUEUE_METRIC;


-- create indexes for the foreign keys to WebSphere MQ queue metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_QUEUE_MONTH ON CTQ.F_QUEUE_MONTH (
       queue_id                  ASC,
       XQ_queu_state_dttm        ASC
);


CREATE INDEX CTQ.XFK2F_QUEUE_MONTH ON CTQ.F_QUEUE_MONTH (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_QUEUE_MONTH ON CTQ.F_QUEUE_MONTH (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_QUEUE_MONTH ON CTQ.F_QUEUE_MONTH (
       metric_id                 ASC
);


-----------------------------------------------------------------------
-- Create WebSphere MQ channel fact tables 
-----------------------------------------------------------------------
                               
-- Hour fact table for all metrics against WebSphere MQ channels
CREATE TABLE CTQ.F_CHNL_HOUR (
         channel_id           INTEGER NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_hour            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (channel_id, XQ_chnl_state_dttm, qmgr_id, XQ_qmgr_state_dttm, 
                            host_id, metric_id, meas_hour)
);

-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_CHNL_<cust_name>_HOUR  
--   AS (SELECT * FROM CTQ.F_CHNL_HOUR WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_CHNL_HOUR
       ADD CONSTRAINT C_1
              FOREIGN KEY (channel_id, XQ_chnl_state_dttm)
                             REFERENCES CTQ.D_CHANNEL;

ALTER TABLE CTQ.F_CHNL_HOUR
       ADD CONSTRAINT C_2
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_CHNL_HOUR
       ADD CONSTRAINT C_3
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_CHNL_HOUR
       ADD CONSTRAINT C_4
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_CHANNEL_METRIC;
                                                     

-- create indexes for the foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_CHNL_HOUR ON CTQ.F_CHNL_HOUR (
       channel_id                ASC,
       XQ_chnl_state_dttm        ASC
);
  
CREATE INDEX CTQ.XFK2F_CHNL_HOUR ON CTQ.F_CHNL_HOUR (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_CHNL_HOUR ON CTQ.F_CHNL_HOUR (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_CHNL_HOUR ON CTQ.F_CHNL_HOUR (
       metric_id                 ASC
);


-- Day fact table for all metrics against WebSphere MQ channels
CREATE TABLE CTQ.F_CHNL_DAY (
         channel_id           INTEGER NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (channel_id, XQ_chnl_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_date)
);

-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_CHNL_<cust_name>_DAY  
--   AS (SELECT * FROM CTQ.F_CHNL_DAY WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_CHNL_DAY
       ADD CONSTRAINT C_5
              FOREIGN KEY (channel_id, XQ_chnl_state_dttm)
                             REFERENCES CTQ.D_CHANNEL;

ALTER TABLE CTQ.F_CHNL_DAY
       ADD CONSTRAINT C_6
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_CHNL_DAY
       ADD CONSTRAINT C_7
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_CHNL_DAY
       ADD CONSTRAINT C_8
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_CHANNEL_METRIC;


-- create indexes for the foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_CHNL_DAY ON CTQ.F_CHNL_DAY (
       channel_id                ASC,
       XQ_chnl_state_dttm        ASC
);
  
CREATE INDEX CTQ.XFK2F_CHNL_DAY ON CTQ.F_CHNL_DAY (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_CHNL_DAY ON CTQ.F_CHNL_DAY (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_CHNL_DAY ON CTQ.F_CHNL_DAY (
       metric_id                 ASC
);


-- Week fact table for all metrics against WebSphere MQ channels
CREATE TABLE CTQ.F_CHNL_WEEK (
         channel_id           INTEGER NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (channel_id, XQ_chnl_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_date)
);
         
-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_CHNL_<cust_name>_WEEK  
--   AS (SELECT * FROM CTQ.F_CHNL_WEEK WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_CHNL_WEEK
       ADD CONSTRAINT C_9
              FOREIGN KEY (channel_id, XQ_chnl_state_dttm)
                             REFERENCES CTQ.D_CHANNEL;

ALTER TABLE CTQ.F_CHNL_WEEK
       ADD CONSTRAINT C_10
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_CHNL_WEEK
       ADD CONSTRAINT C_11
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_CHNL_WEEK
       ADD CONSTRAINT C_12
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_CHANNEL_METRIC;
                          

-- create indexes for the foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_CHNL_WEEK ON CTQ.F_CHNL_WEEK (
       channel_id                ASC,
       XQ_chnl_state_dttm        ASC
);
  
CREATE INDEX CTQ.XFK2F_CHNL_WEEK ON CTQ.F_CHNL_WEEK (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_CHNL_WEEK ON CTQ.F_CHNL_WEEK (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_CHNL_WEEK ON CTQ.F_CHNL_WEEK (
       metric_id                 ASC
);


-- Month fact table for all metrics against WebSphere MQ channels
CREATE TABLE CTQ.F_CHNL_MONTH (
         channel_id           INTEGER NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_date            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (channel_id, XQ_chnl_state_dttm, qmgr_id, XQ_qmgr_state_dttm, 
                            host_id, metric_id, meas_date)
);
         
-- Run this set of inserts to create views for each customer. You must replace 
-- <cust_name> with your valid customer name, and code inserts for each customer.
--
-- CREATE VIEW CTQ.F_V_CHNL_<cust_name>_MONTH  
--   AS (SELECT * FROM CTQ.F_CHNL_MONTH WHERE host_id IN
--   (SELECT host_id FROM CTQ.D_HOST WHERE customer_name = <cust_name>));


-- define foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

ALTER TABLE CTQ.F_CHNL_MONTH
       ADD CONSTRAINT C_13
              FOREIGN KEY (channel_id, XQ_chnl_state_dttm)
                             REFERENCES CTQ.D_CHANNEL;

ALTER TABLE CTQ.F_CHNL_MONTH
       ADD CONSTRAINT C_14
              FOREIGN KEY (qmgr_id, XQ_qmgr_state_dttm)
                             REFERENCES CTQ.D_QMGR;
                           
ALTER TABLE CTQ.F_CHNL_MONTH
       ADD CONSTRAINT C_15
              FOREIGN KEY (host_id)
                             REFERENCES CTQ.D_HOST;

ALTER TABLE CTQ.F_CHNL_MONTH
       ADD CONSTRAINT C_16
              FOREIGN KEY (metric_id)
                             REFERENCES CTQ.D_CHANNEL_METRIC;


-- create indexes for the foreign keys to WebSphere MQ channel metric dimension and 
-- component dimension tables

CREATE INDEX CTQ.XFK1F_CHNL_MONTH ON CTQ.F_CHNL_MONTH (
       channel_id                ASC,
       XQ_chnl_state_dttm        ASC
);
  
CREATE INDEX CTQ.XFK2F_CHNL_MONTH ON CTQ.F_CHNL_MONTH (
       qmgr_id                   ASC,
       XQ_qmgr_state_dttm        ASC
);

CREATE INDEX CTQ.XFK3F_CHNL_MONTH ON CTQ.F_CHNL_MONTH (
       host_id                   ASC
);

CREATE INDEX CTQ.XFK4F_CHNL_MONTH ON CTQ.F_CHNL_MONTH (
       metric_id                 ASC
);


-----------------------------------------------------------------------
-- Create Mart staging tables 
-----------------------------------------------------------------------

-- Staging table for WebSphere MQ queue manager metrics
CREATE TABLE CTQ.STAGE_D_QMGR_MET (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );


-- Staging table for WebSphere MQ queue metrics
CREATE TABLE CTQ.STAGE_D_QUEUE_MET (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );


-- Staging table for WebSphere MQ channel metrics
CREATE TABLE CTQ.STAGE_D_CHNL_MET (
         metric_id      INTEGER NOT NULL,
         met_name       VARCHAR(120) NOT NULL,
         met_desc       VARCHAR(254) NOT NULL,
         met_units      VARCHAR(120) NOT NULL,
         met_category   VARCHAR(10) NOT NULL,
         msrc_nm        VARCHAR(120) NOT NULL,
         min_exists     CHAR(1) NOT NULL,
         max_exists     CHAR(1) NOT NULL,
         avg_exists     CHAR(1) NOT NULL,
         total_exists   CHAR(1) NOT NULL,     
               primary key (metric_id)
 );         


-- Staging table for WebSphere MQ hosts
CREATE TABLE CTQ.STAGE_D_HOST (
         host_id           INTEGER NOT NULL,
         host_name         VARCHAR(254) NOT NULL,
         customer_name     CHAR(120) NOT NULL,
         center_name       CHAR(120) NOT NULL,
               primary key (host_id)
);


-- Staging table for WebSphere MQ queue managers
CREATE TABLE CTQ.STAGE_D_QMGR (
         qmgr_id              INTEGER NOT NULL,
         qmgr_name            VARCHAR(254) NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         platform_type        VARCHAR(120) NOT NULL,
         command_level        VARCHAR(120) NOT NULL,
               primary key (qmgr_id, XQ_qmgr_state_dttm)
);


-- Staging table for WebSphere MQ queues
CREATE TABLE CTQ.STAGE_D_QUEUE (
         queue_id             INTEGER NOT NULL,
         queue_name           VARCHAR(254) NOT NULL,
         XQ_queu_state_dttm   timestamp NOT NULL,
         queue_type           VARCHAR(120) NOT NULL,
         queue_usage          VARCHAR(120) NOT NULL,
               primary key (queue_id, XQ_queu_state_dttm)
);


-- Staging table for WebSphere MQ channels
CREATE TABLE CTQ.STAGE_D_CHANNEL (
         channel_id           INTEGER NOT NULL,
         channel_name         VARCHAR(254) NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         channel_type         VARCHAR(120) NOT NULL,
         protocol_type        VARCHAR(120) NOT NULL,
         transmission_queue   VARCHAR(120),
               primary key (channel_id, XQ_chnl_state_dttm)
);


-- Staging hour fact table for all metric against WebSphere MQ queue managers
CREATE TABLE CTQ.STAGE_F_QMGR_HOUR (
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_hour            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (qmgr_id, XQ_qmgr_state_dttm, host_id, metric_id, meas_hour)
);


-- Staging hour fact table for all metric against WebSphere MQ queues
CREATE TABLE CTQ.STAGE_F_QUEUE_HOUR (
         queue_id             INTEGER NOT NULL,
         XQ_queu_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_hour            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (queue_id, XQ_queu_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_hour)
);


-- Staging hour fact table for all metric against WebSphere MQ channels
CREATE TABLE CTQ.STAGE_F_CHNL_HOUR (
         channel_id           INTEGER NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         qmgr_id              INTEGER NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         host_id              INTEGER NOT NULL,
         metric_id            INTEGER NOT NULL,
         meas_hour            timestamp NOT NULL,
         min_value            FLOAT,
         max_value            FLOAT,
         avg_value            FLOAT,
         total_value          FLOAT,
         sample_count         INTEGER,
               primary key (channel_id, XQ_chnl_state_dttm, qmgr_id, XQ_qmgr_state_dttm,
                            host_id, metric_id, meas_hour)
);



-----------------------------------------------------------------------
-- Create prune mart control and log tables 
-----------------------------------------------------------------------

-- Control table for pruning obsolete data from all WebSphere MQ fact tables 
CREATE TABLE CTQ.PRUNE_MART_CONTROL (
        Table_Name         VARCHAR(120) NOT NULL,
        PMartC_Duration    DECIMAL(8,0) NOT NULL
);

-- Log table for logging th pruning of obsolete data from all WebSphere MQ fact tables
CREATE TABLE CTQ.PRUNE_MART_LOG (
        PMart_Run_DtTM     timestamp NOT NULL,
        Table_Name         VARCHAR(120) NOT NULL,
        PMartC_Duration    DECIMAL(8,0) NOT NULL,
        Number_Pruned      DECIMAL(8,0) NOT NULL
);


