------------------------------------------------------------------------- 
--
-- Licensed Materials - Property of IBM
-- 5724-B99MQ
-- 
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
-- 
-- File Information: MQS/MQS_TEDW/src/tedw_apps_etl/mq510_tdwfp_v1102/ctq/cdw/dml/ctq_cdw_data.sql, MQS_TEDW, amsmqs_5.1.1, 200405251803
-- Revision: 1.2
-- Date: 2/3/04 15:05:30
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Static data for IBM Tivoli Monitoring for Business Integration, 
-- Version 5.1.2 : WebSphere MQ
-----------------------------------------------------------------------                                                                       

--#iftag fixpack_2

UPDATE TWG.MSrc set MSrc_Nm='IBM Tivoli Monitoring for Business Integration, Version 5.1.1 : WebSphere MQ' where MSrc_Cd='CTQ';

-- create temporary table for measurement types
DECLARE global temporary TABLE MsmtTyp (
       MsmtTyp_ID           INTEGER NOT NULL,
		 MUnit_Cd             CHAR(6) NOT NULL,
		 MSrc_Cd 	          CHAR(6) NOT NULL,
       MsmtTyp_Nm           VARCHAR(120) NOT NULL,
		 MsmtTyp_Ds           VARCHAR(254) 
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Queue_messages_in', 'Number of messages that have been put on the queue');
INSERT INTO session.MsmtTyp VALUES(0, 'QTY', 'CTQ', 'Queue_messages_out', 'Number of messages that have been successfully retrieved from the queue');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Queue_messages_in_per_minute', 'Number of messages put on the queue per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Queue_messages_out_per_minute', 'Number of messages retrieved from the queue per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Sec', 'CTQ', 'Queue_reset_interval', 'Time since queue last reset');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_messages_per_minute', 'Number of messages sent or received by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_batches_completed_per_minute', 'Number of completed batches by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_buffers_sent_per_minute', 'Number of transmission buffers sent by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_buffers_received_per_minute', 'Number of transmission buffers received by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_bytes_sent_per_minute', 'Number of bytes sent by a channel per minute');
INSERT INTO session.MsmtTyp VALUES(0, 'Qpm', 'CTQ', 'Channel_bytes_received_per_minute', 'Number of bytes received by a channel per minute');

-- Insert the WebSphere MQ measurement types into the generic schema if not exist already
INSERT INTO TWG.MsmtTyp (MsmtTyp_ID, MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) 
SELECT  
   m.MsmtTyp_ID,
   m.MUnit_Cd,
   m.MSrc_Cd,
   m.MsmtTyp_Nm,
   m.MsmtTyp_Ds
FROM
   session.MsmtTyp m
WHERE NOT EXISTS
( 
  SELECT 1 FROM
   TWG.MsmtTyp t
  WHERE
  t.MsmtTyp_Nm = m.MsmtTyp_Nm
);

-- create temporary table for measurement group members
DECLARE global temporary TABLE MGrpMbr (
      MGrp_Cd              CHAR(6) NOT NULL,
		MGrpTyp_Cd           CHAR(6) NOT NULL,
		MsmtTyp_ID           INTEGER
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'MIN_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
   (
      	'Queue_messages_in_per_minute',
		'Queue_messages_out_per_minute',
		'Queue_reset_interval',
		'Channel_messages_per_minute',
	    'Channel_batches_completed_per_minute',
	    'Channel_buffers_sent_per_minute',
	    'Channel_buffers_received_per_minute',
	    'Channel_bytes_sent_per_minute',
        'Channel_bytes_received_per_minute'
   );
	

INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'MAX_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN 
	(
	   	'Queue_messages_in_per_minute',
		'Queue_messages_out_per_minute',
		'Queue_reset_interval',
		'Channel_messages_per_minute',
	    'Channel_batches_completed_per_minute',
	    'Channel_buffers_sent_per_minute',
	    'Channel_buffers_received_per_minute',
	    'Channel_bytes_sent_per_minute',
        'Channel_bytes_received_per_minute'
	);


INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'AVG_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
	(
		'Queue_messages_in_per_minute',
		'Queue_messages_out_per_minute',
		'Queue_reset_interval',
		'Channel_messages_per_minute',
	    'Channel_batches_completed_per_minute',
	    'Channel_buffers_sent_per_minute',
	    'Channel_buffers_received_per_minute',
	    'Channel_bytes_sent_per_minute',
      'Channel_bytes_received_per_minute'
   );	

INSERT INTO session.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT
	'TOT_E',
	'GROUP',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
	(
	   	'Queue_messages_in',
		'Queue_messages_out'
   );                   

	
-- Insert the measurment group members into the generic schema if not exist already
INSERT INTO TWG.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
SELECT 
   m.MGrp_Cd,
   m.MGrpTyp_Cd,
   m.MsmtTyp_ID
FROM 
   session.MGrpMbr m
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.MGrpMbr t
  WHERE
  t.MGrpTyp_Cd = m.MGrpTyp_CD AND 
  t.MGrp_Cd = m.MGrp_Cd AND 
  t.MsmtTyp_ID = m.MsmtTyp_ID
);
	

-- create temporary table for measurement rules
DECLARE global temporary TABLE MsmtRul (
      CompTyp_Cd           CHAR(17) NOT NULL,
		MsmtTyp_ID           INTEGER
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;
	
INSERT INTO session.MsmtRul (CompTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQ_QUEUE',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN
	(
   	'Queue_messages_in',
		'Queue_messages_out',
		'Queue_messages_in_per_minute',
		'Queue_messages_out_per_minute',
		'Queue_reset_interval'
   );
	
INSERT INTO session.MsmtRul (CompTyp_Cd, MsmtTyp_ID)
SELECT
	'CTQ_CHANNEL',
	m.MsmtTyp_ID
FROM
	TWG.MsmtTyp m
WHERE 
	m.MsmtTyp_Nm IN 
	(
      'Channel_messages_per_minute',
	  'Channel_batches_completed_per_minute',
	  'Channel_buffers_sent_per_minute',
	  'Channel_buffers_received_per_minute',
	  'Channel_bytes_sent_per_minute',
      'Channel_bytes_received_per_minute'
	);
	

-- Insert the measurement rules in the generic schema if not exist already
INSERT INTO TWG.MsmtRul (CompTyp_Cd, MsmtTyp_ID)
SELECT 
   m.CompTyp_Cd,
   m.MsmtTyp_ID
FROM 
   session.MsmtRul m
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  TWG.MsmtRul t
  WHERE
  t.CompTyp_Cd = m.CompTyp_Cd AND 
  t.MsmtTyp_ID = m.MsmtTyp_ID
);

-----------------------------------------------------------------------
-- Insert static data into the WebSphere MQ staging tables 
-----------------------------------------------------------------------

-- create temporary table for min_exists
DECLARE global temporary TABLE temp_min_exists (
   msmttyp_id	   INTEGER,
   min_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_min_exists (msmttyp_id, min_exists)
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MGrpMbr mb,
   TWG.Msmttyp m
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'MIN_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;


-- create temporary table for max_exists
DECLARE global temporary TABLE temp_max_exists (
   msmttyp_id	   INTEGER,
   max_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_max_exists (msmttyp_id, max_exists)
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MgrpMbr mb,
   TWG.Msmttyp m 
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'MAX_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;


-- create temporary table for avg_exists
DECLARE global temporary TABLE temp_avg_exists (
   msmttyp_id	   INTEGER,
   avg_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_avg_exists (msmttyp_id, avg_exists)
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MgrpMbr mb,
   TWG.Msmttyp m 
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'AVG_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;


-- create temporary table for tot_exists
DECLARE global temporary TABLE temp_tot_exists (
   msmttyp_id	   INTEGER,
   tot_exists     CHAR(1)
)
WITH REPLACE ON COMMIT preserve ROWS NOT logged 
; 
 
INSERT INTO session.temp_tot_exists (msmttyp_id, tot_exists) 
SELECT
   mb.msmttyp_id,
   'Y'
FROM
   TWG.MgrpMbr mb,
   TWG.Msmttyp m 
WHERE
   mb.mgrptyp_cd = 'GROUP' AND
   mb.mgrp_cd = 'TOT_E' AND 
   mb.msmttyp_id = m.msmttyp_id AND 
   m.MSrc_Cd = 'CTQ'
;



DELETE FROM CTQ.QMGR_METRIC;
DELETE FROM CTQ.QUEUE_METRIC;
DELETE FROM CTQ.CHANNEL_METRIC;


INSERT INTO CTQ.QMGR_METRIC (insert_dttm, metric_id, met_name, met_desc, met_units,
                             met_category, msrc_nm, min_exists, max_exists, avg_exists,
                             total_exists)
SELECT
   current timestamp - current timezone,
   mt.msmttyp_id,
   mt.msmttyp_nm,
   mt.msmttyp_ds,
   mu1.munit_nm,
   'not used',
   ms.msrc_nm,
   value(min_exists,'N'),
   value(max.max_exists,'N'),
   value(avg.avg_exists,'N'),
   value(tot.tot_exists,'N')
FROM
   TWG.msmttyp mt left outer join session.temp_min_exists min
   ON mt.msmttyp_id = min.msmttyp_id,
   TWG.msmttyp mt2 left outer join session.temp_max_exists max
   ON mt2.msmttyp_id = max.msmttyp_id,
   TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
   ON mt3.msmttyp_id = avg.msmttyp_id,
   TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
   ON mt4.msmttyp_id = tot.msmttyp_id,
   TWG.MsmtRul mr,
   TWG.Mgrp mg1,
   TWG.MgrpMbr mb1,
   TWG.MUnit mu1,
   TWG.Msrc ms
WHERE
   mt.msmttyp_id = mr.msmttyp_id AND
   mr.comptyp_cd = 'CTQ_QMGR' AND
   mt.MSrc_Cd = 'CTQ' AND
   mt.msmttyp_id = mt2.msmttyp_id AND
   mt.msmttyp_id = mt3.msmttyp_id AND
   mt.msmttyp_id = mt4.msmttyp_id AND
   mb1.mgrp_cd = mg1.mgrp_cd AND
   mb1.mgrptyp_cd = 'GROUP' AND
   mt.munit_cd = mu1.munit_cd AND
   ms.msrc_cd = 'CTQ' AND 
   NOT EXISTS
   ( 
    SELECT 1 FROM
    CTQ.QMGR_METRIC s
    WHERE
    mt.msmttyp_id = s.metric_id
   )
GROUP BY
   mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mu1.munit_nm, ms.msrc_nm, 
   min_exists, avg_exists, tot_exists, max_exists
;


INSERT INTO CTQ.QUEUE_METRIC (insert_dttm, metric_id, met_name, met_desc, met_units,
                              met_category, msrc_nm, min_exists, max_exists, avg_exists,
                              total_exists)
SELECT
   current timestamp - current timezone,
   mt.msmttyp_id,
   mt.msmttyp_nm,
   mt.msmttyp_ds,
   mu1.munit_nm,
   'not used',
   ms.msrc_nm,
   value(min_exists,'N'),
   value(max.max_exists,'N'),
   value(avg.avg_exists,'N'),
   value(tot.tot_exists,'N')
FROM
   TWG.msmttyp mt left outer join session.temp_min_exists min
   ON mt.msmttyp_id = min.msmttyp_id,
   TWG.msmttyp mt2 left outer join session.temp_max_exists max
   ON mt2.msmttyp_id = max.msmttyp_id,
   TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
   ON mt3.msmttyp_id = avg.msmttyp_id,
   TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
   ON mt4.msmttyp_id = tot.msmttyp_id,
   TWG.MsmtRul mr,
   TWG.Mgrp mg1,
   TWG.MgrpMbr mb1,
   TWG.MUnit mu1,
   TWG.MSrc ms
WHERE
   mt.msmttyp_id = mr.msmttyp_id AND 
   mr.comptyp_cd = 'CTQ_QUEUE' AND
   mt.MSrc_Cd = 'CTQ' AND
   mt.msmttyp_id = mt2.msmttyp_id AND
   mt.msmttyp_id = mt3.msmttyp_id AND
   mt.msmttyp_id = mt4.msmttyp_id AND
   mb1.mgrp_cd = mg1.mgrp_cd AND
   mb1.mgrptyp_cd = 'GROUP' AND 
   mt.munit_cd = mu1.munit_cd AND
   ms.msrc_cd = 'CTQ' AND 
   NOT EXISTS
   ( 
    SELECT 1 FROM
    CTQ.QUEUE_METRIC s
    WHERE
    mt.msmttyp_id = s.metric_id
   ) 
GROUP BY
   mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mu1.munit_nm, ms.msrc_nm, 
   min_exists, avg_exists, tot_exists, max_exists
;



INSERT INTO CTQ.CHANNEL_METRIC (insert_dttm, metric_id, met_name, met_desc, met_units,
                                met_category, msrc_nm, min_exists, max_exists, avg_exists,
                                total_exists)
SELECT
   current timestamp - current timezone,
   mt.msmttyp_id,
   mt.msmttyp_nm,
   mt.msmttyp_ds,
   mu1.munit_nm,
   'not used',
   ms.msrc_nm,
   value(min_exists,'N'),
   value(max.max_exists,'N'),
   value(avg.avg_exists,'N'),
   value(tot.tot_exists,'N')
FROM
   TWG.msmttyp mt left outer join session.temp_min_exists min
   ON mt.msmttyp_id = min.msmttyp_id,
   TWG.msmttyp mt2 left outer join session.temp_max_exists max
   ON mt2.msmttyp_id = max.msmttyp_id,
   TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
   ON mt3.msmttyp_id = avg.msmttyp_id,
   TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
   ON mt4.msmttyp_id = tot.msmttyp_id,
   TWG.MsmtRul mr,
   TWG.Mgrp mg1,
   TWG.MgrpMbr mb1,
   TWG.MUnit mu1,
   TWG.Msrc ms
WHERE
   mt.msmttyp_id = mr.msmttyp_id AND 
   mr.comptyp_cd = 'CTQ_CHANNEL' AND
   mt.msrc_cd = 'CTQ' AND
   mt.msmttyp_id = mt2.msmttyp_id AND
   mt.msmttyp_id = mt3.msmttyp_id AND
   mt.msmttyp_id = mt4.msmttyp_id AND
   mb1.mgrp_cd = mg1.mgrp_cd AND
   mb1.mgrptyp_cd = 'GROUP' AND
   mt.munit_cd = mu1.munit_cd AND
   ms.msrc_cd = 'CTQ' AND 
   NOT EXISTS
   ( 
    SELECT 1 FROM
    CTQ.CHANNEL_METRIC s
    WHERE
    mt.msmttyp_id = s.metric_id
   )
GROUP BY
   mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mu1.munit_nm, ms.msrc_nm, 
   min_exists, avg_exists, tot_exists, max_exists
;

--#endtag fixpack_2