------------------------------------------------------------------------- 
--
-- Licensed Materials - Property of IBM
-- 5724-B99MQ
-- 
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
-- 
-- File Information: MQS/MQS_TEDW/src/tedw_apps_etl/mq510_tdwfp_v1102/ctq/etl/sql/ctq_m10_s010_component.db2, MQS_TEDW, amsmqs_5.1.1, 200405251803
-- Revision: 1.2
-- Date: 1/30/04 12:47:33
--
-----------------------------------------------------------------------

--#VERSION 1.1.0.1.0

-----------------------------------------------------------------------
--  insert WebSphere MQ host component information 
-----------------------------------------------------------------------

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTQ.STAGE_D_HOST;

--#EXECUTE_AT_TARGET
create table CTQ.STAGE_D_HOST (
         host_id           INTEGER NOT NULL,
         host_name         VARCHAR(254) NOT NULL,
         customer_name     VARCHAR(120) NOT NULL,
         center_name       VARCHAR(120) NOT NULL,
               primary key (host_id)
);


-- set the high value for the window
update TWG.Extract_Control set
    extctl_to_intseq = (select 
                            max(cr.comp_source_id) 
                        from 
                            TWG.Cur_Comp c, 
                            TWG.Cur_CompReln cr
                        where 
                            cr.relntyp_cd = 'PCHILD' and 
                            cr.comp_target_id = c.comp_id and
                            c.comptyp_cd = 'CTQ_QMGR')
where  
    extctl_source='TWG.COMP' and
    extctl_target='CTQ.D_HOST' and
   (select 
        count(*) 
    from 
        TWG.Cur_Comp c, 
        TWG.Cur_CompReln cr
    where 
        cr.relntyp_cd = 'PCHILD' and 
        cr.comp_target_id = c.comp_id and 
        c.comptyp_cd = 'CTQ_QMGR') > 0
;


--#INSERT_INTO_TARGET
-- insert WebSphere MQ host compononent information into staging table
insert into CTQ.STAGE_D_HOST (host_id, host_name, customer_name, center_name)
select 
    c1.comp_id,
    c1.comp_nm,
    cu.cust_nm,
    ce.centr_nm
from
    TWG.Cur_Comp c1,
    TWG.Cur_Comp c2,
    TWG.Cur_CompReln cr,
    TWG.Cust cu,
    TWG.Centr ce,
    TWG.Extract_Control ec
where
    ec.extctl_source = 'TWG.COMP' and
    ec.extctl_target = 'CTQ.D_HOST' and
    c1.comp_id > ec.extctl_from_intseq and
    c1.comp_id <= ec.extctl_to_intseq and
    c1.comp_id = cr.comp_source_id and
    cr.relntyp_cd = 'PCHILD' and
    cr.comp_target_id = c2.comp_id and 
    c2.comptyp_cd = 'CTQ_QMGR' and 
    c1.cust_id = cu.cust_id and
    c1.centr_cd = ce.centr_cd 
group by
    c1.comp_id, c1.comp_nm, cu.cust_nm,  ce.centr_nm
;


--#EXECUTE_AT_TARGET
-- copy WebSphere MQ host component information from staging table into component
-- dimension table
insert into CTQ.D_HOST (host_id, host_name, customer_name, center_name)
select 
    s.host_id,
    s.host_name,
    s.customer_name,
    s.center_name
from CTQ.STAGE_D_HOST s
where not exists
(
    select 1 from 
        CTQ.D_HOST d
    where
        d.host_id = s.host_id
);
        

-- confirm that the insertion of data by inserting a row into TWG.EXTRACT_LOG.
insert into twg.extract_log (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq,
                             extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm,
                             extlog_to_dttm)
select
    ec.extctl_source,
    ec.extctl_target,
    current timestamp - current timezone,
    ec.extctl_from_rawseq,
    ec.extctl_to_rawseq,
    ec.extctl_from_intseq,
    ec.extctl_to_intseq,
    ec.extctl_from_dttm,
    ec.extctl_to_dttm
from 
    TWG.Extract_control ec
where
    ec.extctl_source = 'TWG.COMP' and
    ec.extctl_target = 'CTQ.D_HOST'
; 


 
-----------------------------------------------------------------------
--  insert WebSphere MQ queue manager component information 
-----------------------------------------------------------------------

--#IGNORE_ERROR
drop table CTQ.STAGE_QMGR_KEY;

create table CTQ.STAGE_QMGR_KEY (
         comp_id              INTEGER NOT NULL,
         comp_nm              VARCHAR(254) NOT NULL,
         compattr_strt_dttm   timestamp NOT NULL,
            primary key (comp_id, compattr_strt_dttm)
);


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTQ.STAGE_D_QMGR;

--#EXECUTE_AT_TARGET
create table CTQ.STAGE_D_QMGR (
         qmgr_id              INTEGER NOT NULL,
         qmgr_name            VARCHAR(254) NOT NULL,
         XQ_qmgr_state_dttm   timestamp NOT NULL,
         platform_type        VARCHAR(120) NOT NULL,
         command_level        VARCHAR(120) NOT NULL,
               primary key (qmgr_id, XQ_qmgr_state_dttm)
);


-- set the high value for the window
update TWG.Extract_Control set
    extctl_to_intseq =  (select 
                            max(ca.compattr_id) 
                         from 
                            TWG.Cur_Comp c, 
                            TWG.Cur_CompAttr ca
                         where
                            c.comptyp_cd = 'CTQ_QMGR' and
                            c.comp_id = ca.comp_id and
                            ca.attrtyp_cd in ('CTQ_QMGRPLATFORM', 'CTQ_QMGRCMDLVL')
                        )
where  
    extctl_source='TWG.COMPATTR' and
    extctl_target='CTQ.D_QMGR' and
   (select 
        count(*) 
    from 
        TWG.Cur_Comp c,
        TWG.Cur_CompAttr ca
    where
        c.comptyp_cd = 'CTQ_QMGR' and
        c.comp_id = ca.comp_id and
        ca.attrtyp_cd in ('CTQ_QMGRPLATFORM', 'CTQ_QMGRCMDLVL')) > 0
;


-- insert WebSphere MQ queue manager component primary keys into staging table
insert into CTQ.STAGE_QMGR_KEY (comp_id, comp_nm, compattr_strt_dttm)
select 
    c.comp_id,
    c.comp_nm,
    max(ca.compattr_strt_dttm) 
from
    TWG.Cur_Comp c,
    TWG.Cur_CompAttr ca,
    TWG.Extract_Control ec
where
    ec.extctl_source = 'TWG.COMPATTR' and
    ec.extctl_target = 'CTQ.D_QMGR' and
    ca.compattr_id > ec.extctl_from_intseq and
    ca.compattr_id <= ec.extctl_to_intseq and
    c.comptyp_cd = 'CTQ_QMGR' and
    c.comp_id = ca.comp_id and
    ca.attrtyp_cd in ('CTQ_QMGRPLATFORM', 'CTQ_QMGRCMDLVL')   
group by
    c.comp_id, c.comp_nm 
;
                        

--#INSERT_INTO_TARGET
-- insert WebSphere MQ queue manager component information into staging table
insert into CTQ.STAGE_D_QMGR (qmgr_id, qmgr_name, XQ_qmgr_state_dttm, platform_type, command_level) 
select 
    s.comp_id,
    s.comp_nm,
    s.compattr_strt_dttm, 
    ca1.compattr_val,
    ca2.compattr_val
from
    CTQ.STAGE_QMGR_KEY s,
    TWG.Cur_Comp c,
    TWG.Cur_CompAttr ca1,
    TWG.Cur_CompAttr ca2
where
    s.comp_id = c.comp_id and
    c.comptyp_cd = 'CTQ_QMGR' and
    s.comp_id = ca1.comp_id and 
    ca1.attrtyp_cd = 'CTQ_QMGRPLATFORM' and
    s.comp_id = ca2.comp_id and 
    ca2.attrtyp_cd = 'CTQ_QMGRCMDLVL'  
group by
    s.comp_id, s.comp_nm, s.compattr_strt_dttm, ca1.compattr_val, ca2.compattr_val 
;


--#EXECUTE_AT_TARGET
-- copy WebSphere MQ queue manager component information from staging table into component
-- dimension table
insert into CTQ.D_QMGR (qmgr_id, qmgr_name, XQ_qmgr_state_dttm, platform_type, command_level)
select 
    s.qmgr_id,
    s.qmgr_name,
    s.XQ_qmgr_state_dttm, 
    s.platform_type,
    s.command_level
from CTQ.STAGE_D_QMGR s
where not exists
(
    select 1 from 
        CTQ.D_QMGR d
    where
        d.qmgr_id = s.qmgr_id and
        d.XQ_qmgr_state_dttm = s.XQ_qmgr_state_dttm
);


-- confirm insertion of data by inserting a row into TWG.EXTRACT_LOG.
insert into twg.extract_log (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq,
                             extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm,
                             extlog_to_dttm)
select
    ec.extctl_source,
    ec.extctl_target,
    current timestamp - current timezone,
    ec.extctl_from_rawseq,
    ec.extctl_to_rawseq,
    ec.extctl_from_intseq,
    ec.extctl_to_intseq,
    ec.extctl_from_dttm,
    ec.extctl_to_dttm
from 
    TWG.Extract_control ec
where
    ec.extctl_source = 'TWG.COMPATTR' and
    ec.extctl_target = 'CTQ.D_QMGR'
; 


-----------------------------------------------------------------------
--  insert WebSphere MQ queue component information 
-----------------------------------------------------------------------

--#IGNORE_ERROR
drop table CTQ.STAGE_QUEUE_KEY;

create table CTQ.STAGE_QUEUE_KEY (
         comp_id              INTEGER NOT NULL,
         comp_nm              VARCHAR(254) NOT NULL,
         compattr_strt_dttm   timestamp NOT NULL,
            primary key (comp_id, compattr_strt_dttm)
);


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTQ.STAGE_D_QUEUE;

--#EXECUTE_AT_TARGET
create table CTQ.STAGE_D_QUEUE (
         queue_id           INTEGER NOT NULL,
         queue_name         VARCHAR(254),
         XQ_queu_state_dttm timestamp NOT NULL,
         queue_type         VARCHAR(120) NOT NULL,
         queue_usage        VARCHAR(120) NOT NULL,
               primary key (queue_id, XQ_queu_state_dttm)
);


-- set the high value for the window
update TWG.Extract_Control set
    extctl_to_intseq =  (select 
                            max(ca.compattr_id) 
                         from 
                            TWG.Cur_Comp c, 
                            TWG.Cur_CompAttr ca
                         where
                            c.comptyp_cd = 'CTQ_QUEUE' and
                            c.comp_id = ca.comp_id and
                            ca.attrtyp_cd in ('CTQ_QUEUETYPE', 'CTQ_QUEUEUSAGE')
                        )
where  
    extctl_source='TWG.COMPATTR' and
    extctl_target='CTQ.D_QUEUE' and
   (select 
        count(*) 
    from 
        TWG.Cur_Comp c,
        TWG.Cur_CompAttr ca
    where
        c.comptyp_cd = 'CTQ_QUEUE' and
        c.comp_id = ca.comp_id and
        ca.attrtyp_cd in ('CTQ_QUEUETYPE', 'CTQ_QUEUEUSAGE')) > 0
;


-- insert WebSphere MQ queue component primary keys and name information
-- into temporary table
insert into CTQ.STAGE_QUEUE_KEY (comp_id, comp_nm, compattr_strt_dttm)
select 
    c.comp_id,
    c.comp_nm,
    max(ca.compattr_strt_dttm)
from
    TWG.Cur_Comp c,
    TWG.Cur_CompAttr ca,
    TWG.Extract_Control ec
where
    ec.extctl_source = 'TWG.COMPATTR' and
    ec.extctl_target = 'CTQ.D_QUEUE' and
    ca.compattr_id > ec.extctl_from_intseq and
    ca.compattr_id <= ec.extctl_to_intseq and
    c.comptyp_cd = 'CTQ_QUEUE' and
    c.comp_id = ca.comp_id and
    ca.attrtyp_cd in ('CTQ_QUEUETYPE', 'CTQ_QUEUEUSAGE')   
group by
    c.comp_id, c.comp_nm 
;


--#INSERT_INTO_TARGET
-- insert WebSphere MQ queue component information into staging table
insert into CTQ.STAGE_D_QUEUE (queue_id, queue_name, XQ_queu_state_dttm, queue_type, queue_usage)
select 
    s.comp_id,
    s.comp_nm,
    s.compattr_strt_dttm,
    ca1.compattr_val,
    ca2.compattr_val
from
    CTQ.STAGE_QUEUE_KEY s,
    TWG.Cur_Comp c,
    TWG.Cur_CompAttr ca1,
    TWG.Cur_CompAttr ca2
where
    s.comp_id = c.comp_id and
    c.comptyp_cd = 'CTQ_QUEUE' and
    s.comp_id = ca1.comp_id and 
    ca1.attrtyp_cd = 'CTQ_QUEUETYPE' and
    s.comp_id = ca2.comp_id and 
    ca2.attrtyp_cd = 'CTQ_QUEUEUSAGE'  
group by
    s.comp_id, s.comp_nm, s.compattr_strt_dttm, ca1.compattr_val, ca2.compattr_val 
;


--#EXECUTE_AT_TARGET
-- copy WebSphere MQ queue component information from staging table into component
-- dimension table
insert into CTQ.D_QUEUE (queue_id, queue_name, XQ_queu_state_dttm, queue_type, queue_usage)
select 
    s.queue_id,
    s.queue_name,
    s.XQ_queu_state_dttm,
    s.queue_type,
    s.queue_usage
from CTQ.STAGE_D_QUEUE s
where not exists
(
    select 1 from 
        CTQ.D_QUEUE d
    where
        d.queue_id = s.queue_id and
        d.XQ_queu_state_dttm = s.XQ_queu_state_dttm
);


-- confirm insertion of data by inserting a row into TWG.EXTRACT_LOG.
insert into twg.extract_log (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq,
                             extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm,
                             extlog_to_dttm)
select
    ec.extctl_source,
    ec.extctl_target,
    current timestamp - current timezone,
    ec.extctl_from_rawseq,
    ec.extctl_to_rawseq,
    ec.extctl_from_intseq,
    ec.extctl_to_intseq,
    ec.extctl_from_dttm,
    ec.extctl_to_dttm
from 
    TWG.Extract_control ec
where
    ec.extctl_source = 'TWG.COMPATTR' and
    ec.extctl_target = 'CTQ.D_QUEUE'
; 


-----------------------------------------------------------------------
--  insert WebSphere MQ channel component information 
-----------------------------------------------------------------------

--#IGNORE_ERROR
drop table CTQ.STAGE_CHANNEL_KEY;

create table CTQ.STAGE_CHANNEL_KEY (
         comp_id              INTEGER NOT NULL,
         comp_nm              VARCHAR(254) NOT NULL,
         compattr_strt_dttm   timestamp NOT NULL,
            primary key (comp_id, compattr_strt_dttm)
);


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTQ.STAGE_D_CHANNEL;

--#EXECUTE_AT_TARGET
create table CTQ.STAGE_D_CHANNEL (
         channel_id           INTEGER NOT NULL,
         channel_name         VARCHAR(254) NOT NULL,
         XQ_chnl_state_dttm   timestamp NOT NULL,
         channel_type         VARCHAR(120) NOT NULL,
         protocol_type        VARCHAR(120) NOT NULL,
         transmission_queue   VARCHAR(120),
               primary key (channel_id, XQ_chnl_state_dttm)
);


-- set the high value for the window
update TWG.Extract_Control set
    extctl_to_intseq =  (select 
                            max(ca.compattr_id) 
                         from 
                            TWG.Cur_Comp c, 
                            TWG.Cur_CompAttr ca
                         where
                            c.comptyp_cd = 'CTQ_CHANNEL' and
                            c.comp_id = ca.comp_id and
                            ca.attrtyp_cd in ('CTQ_CHANNELTYPE', 'CTQ_CHANNELPROT', 'CTQ_CHANNELTRANS')
                        )
where  
    extctl_source='TWG.COMPATTR' and
    extctl_target='CTQ.D_CHANNEL' and
   (select 
        count(*) 
    from 
        TWG.Cur_Comp c,
        TWG.Cur_CompAttr ca
    where
        c.comptyp_cd = 'CTQ_CHANNEL' and
        c.comp_id = ca.comp_id and
        ca.attrtyp_cd in ('CTQ_CHANNELTYPE', 'CTQ_CHANNELPROT', 'CTQ_CHANNELTRANS')) > 0
;


-- insert WebSphere MQ channel component primary keys and name information
-- into temporary table
insert into CTQ.STAGE_CHANNEL_KEY (comp_id, comp_nm, compattr_strt_dttm) 
select 
    c.comp_id,
    c.comp_nm,
    max(ca.compattr_strt_dttm)
from
    TWG.Cur_Comp c,
    TWG.Cur_CompAttr ca,
    TWG.Extract_Control ec
where
    ec.extctl_source = 'TWG.COMPATTR' and
    ec.extctl_target = 'CTQ.D_CHANNEL' and
    ca.compattr_id > ec.extctl_from_intseq and
    ca.compattr_id <= ec.extctl_to_intseq and
    c.comptyp_cd = 'CTQ_CHANNEL' and
    c.comp_id = ca.comp_id and
    ca.attrtyp_cd in ('CTQ_CHANNELTYPE', 'CTQ_CHANNELPROT', 'CTQ_CHANNELTRANS')   
group by
    c.comp_id, c.comp_nm 
;

               
--#INSERT_INTO_TARGET
-- insert WebSphere MQ channel component information into staging table
insert into CTQ.STAGE_D_CHANNEL (channel_id, channel_name, XQ_chnl_state_dttm, channel_type,
                                 protocol_type, transmission_queue)
select 
    s.comp_id,
    s.comp_nm,
    s.compattr_strt_dttm,
    ca1.compattr_val,
    ca2.compattr_val,
    ca3.compattr_val
from
    CTQ.STAGE_CHANNEL_KEY s,
    TWG.Cur_Comp c,
    TWG.Cur_CompAttr ca1,
    TWG.Cur_CompAttr ca2,
    TWG.Cur_CompAttr ca3
where
    s.comp_id = c.comp_id and
    c.comptyp_cd = 'CTQ_CHANNEL' and
    s.comp_id = ca1.comp_id and 
    ca1.attrtyp_cd = 'CTQ_CHANNELTYPE' and
    s.comp_id = ca2.comp_id and 
    ca2.attrtyp_cd = 'CTQ_CHANNELPROT' and
    s.comp_id = ca3.comp_id and 
    ca3.attrtyp_cd = 'CTQ_CHANNELTRANS'
group by
    s.comp_id, s.comp_nm, s.compattr_strt_dttm, ca1.compattr_val, ca2.compattr_val, ca3.compattr_val 
;    


--#EXECUTE_AT_TARGET
-- copy WebSphere MQ channel component information from staging table into component
-- dimension table
insert into CTQ.D_CHANNEL (channel_id, channel_name, XQ_chnl_state_dttm, channel_type,
                           protocol_type, transmission_queue)
select 
    s.channel_id,
    s.channel_name,
    s.XQ_chnl_state_dttm,
    s.channel_type,
    s.protocol_type,
    s.transmission_queue 
from CTQ.STAGE_D_CHANNEL s
where not exists
(
    select 1 from 
        CTQ.D_CHANNEL d
    where
        d.channel_id = s.channel_id and
        d.XQ_chnl_state_dttm = s.XQ_chnl_state_dttm
);


-- confirm insertion of data by inserting a row into TWG.EXTRACT_LOG.
insert into twg.extract_log (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq,
                             extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm,
                             extlog_to_dttm)
select
    ec.extctl_source,
    ec.extctl_target,
    current timestamp - current timezone,
    ec.extctl_from_rawseq,
    ec.extctl_to_rawseq,
    ec.extctl_from_intseq,
    ec.extctl_to_intseq,
    ec.extctl_from_dttm,
    ec.extctl_to_dttm 
from 
    TWG.Extract_control ec
where
    ec.extctl_source = 'TWG.COMPATTR' and
    ec.extctl_target = 'CTQ.D_CHANNEL'
;
